@@ -136,7 +136,8 @@ adapt_create_number (gunichar ucs4_word[MAX_WORD_LEN + 1])
 	if (rand () % 3)
 		snprintf (word, MAX_WORD_LEN + 1, "%i", rand () % 3101 - 999);
 	else
-		snprintf (word, MAX_WORD_LEN + 1, "%.2f", (rand () % 10000 - 2000) + (rand () % 100) / 100.0);
+		snprintf (word, MAX_WORD_LEN + 1, "%.2f",
+			  (rand () % 10000 - 2000) + (rand () % 100) / 100.0);
 	word[MAX_WORD_LEN] = '\0';
 
 	tmp_ucs4 = g_utf8_to_ucs4_fast (word, -1, &n);
@@ -166,20 +167,21 @@ adapt_comment (gdouble accuracy)
 
 	else if (accuracy < 90)
 		tmp_str = g_strdup (_(" You are not ready to practice this exercise.\n"
-				      " Your accuracy rate is below 90 %%...\n"
+				      " Your accuracy rate is below 90 %...\n"
 				      " Try to accomplish most of the basic course lessons.\n"));
 	else if (accuracy < 95)
 		tmp_str =
 			g_strdup (_
 				  (" You are doing well. But...\n"
-				   " Could you make the accuracy reach at least 95 %%?\n"));
+				   " Could you make the accuracy reach at least 95 %?\n"));
 	else if (accuracy < 99)
 		tmp_str = g_strdup (_(" You are almost there,"
-				      " but your accuracy rate is still below 99 %%.\n"
-				      " Try a few more times," " so that I can evaluate your velocity.\n"));
+				      " but your accuracy rate is still below 99 %.\n"
+				      " Try a few more times,"
+				      " so that I can evaluate your velocity.\n"));
 	else
 		tmp_str = g_strdup (_(" Very good!\n"
-				      " You succeeded with an accuracy rate above 99 %%.\n"
+				      " You succeeded with an accuracy rate above 99 %.\n"
 				      " Now it is time to increase your velocity.\n"
 				      " Go to the 3rd exercise at the main menu.\n"));
 
