@@ -126,7 +126,9 @@ basic_init_char_set ()
 	wg = lookup_widget (window_tutor_, "togglebutton_edit_basic_lesson");
 	if (basic.lesson > 43 && basic.lesson <= 50)
 	{
-		lesson_file = g_strdup_printf ("%sbasic_lesson_%i.txt", main_get_user_dir (), basic.lesson);
+		lesson_file =
+			g_strdup_printf ("%sbasic_lesson_%i.txt", main_get_user_dir (),
+					 basic.lesson);
 		if (g_file_get_contents (lesson_file, &lesson_str, NULL, NULL))
 		{
 			tmpuc = g_utf8_to_ucs4_fast (lesson_str, -1, &basic.char_set_size);
@@ -336,7 +338,9 @@ basic_comment (gdouble accuracy)
 	 * Comments
 	 */
 	if (accuracy < 95.0)
-		tmp_str = g_strdup (_(" You did not succeed.\n The accuracy must be above 95 %%.\n Try again!\n"));
+		tmp_str =
+			g_strdup (_
+				  (" You did not succeed.\n The accuracy must be above 95 %.\n Try again!\n"));
 	else
 	{
 		basic_set_lesson (basic.lesson + 1);
@@ -352,7 +356,9 @@ basic_comment (gdouble accuracy)
 					      " There you will practice mainly the accuracy.\n"));
 		}
 		else
-			tmp_str = g_strdup (_(" All right, now you got it!\n Go to the next lesson.\n"));
+			tmp_str =
+				g_strdup (_
+					  (" All right, now you got it!\n Go to the next lesson.\n"));
 
 		basic_init_char_set ();
 		if (basic.lesson != 50)
