@@ -26,6 +26,7 @@
 #include "basic.h"
 #include "velocity.h"
 #include "fluidness.h"
+#include "top10.h"
 #include "callbacks.h"
 
 /*
@@ -36,12 +37,16 @@ extern GtkWidget *window_tutor_;
 extern GtkWidget *window_keyboard_;
 extern GtkWidget *window_hints_;
 extern GtkWidget *window_stat_;
+extern GtkWidget *window_top10_;
 
 GtkWidget *popup_other_ = NULL;
 GtkWidget *filechooser_tutor = NULL;
 GtkWidget *fontselectiondialog_tutor = NULL;
+GtkClipboard *clipboard = NULL;
+GtkClipboard *clipboard_2 = NULL;
 
 gboolean callbacks_shield = FALSE;
+gboolean mesg_drag_drop = FALSE;
 
 void
 callbacks_shield_set (gboolean state)
@@ -177,7 +182,8 @@ on_button_change_language_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dialog_confirm;
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "CHANGE");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")),
+			    "CHANGE");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -253,6 +259,66 @@ on_button_fluid_clicked (GtkButton * button, gpointer user_data)
 }
 
 
+/**********************************************************************
+ * Control starting over preference
+ */
+
+void
+on_checkbutton_0_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	gboolean autostart;
+
+	autostart = !gtk_toggle_button_get_active (togglebutton);
+
+	main_preferences_set_boolean ("interface", "autostart", autostart);
+
+	gtk_widget_set_sensitive (lookup_widget (window_main_, "radiobutton_1"), autostart);
+	gtk_widget_set_sensitive (lookup_widget (window_main_, "radiobutton_2"), autostart);
+	gtk_widget_set_sensitive (lookup_widget (window_main_, "radiobutton_3"), autostart);
+	gtk_widget_set_sensitive (lookup_widget (window_main_, "radiobutton_4"), autostart);
+
+	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON
+				    (lookup_widget (window_main_, "radiobutton_1")), autostart);
+	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON
+				    (lookup_widget (window_main_, "radiobutton_2")), autostart);
+	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON
+				    (lookup_widget (window_main_, "radiobutton_3")), autostart);
+	gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON
+				    (lookup_widget (window_main_, "radiobutton_4")), autostart);
+}
+
+void
+on_radiobutton_1_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (!gtk_toggle_button_get_active (togglebutton))
+		return;
+	main_preferences_set_int ("interface", "exercise", 1);
+}
+
+void
+on_radiobutton_2_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (!gtk_toggle_button_get_active (togglebutton))
+		return;
+	main_preferences_set_int ("interface", "exercise", 2);
+}
+
+void
+on_radiobutton_3_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (!gtk_toggle_button_get_active (togglebutton))
+		return;
+	main_preferences_set_int ("interface", "exercise", 3);
+}
+
+void
+on_radiobutton_4_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (!gtk_toggle_button_get_active (togglebutton))
+		return;
+	main_preferences_set_int ("interface", "exercise", 4);
+}
+
 /**********************************************************************
  * More two shared info-dialog callbacks
  */
@@ -329,7 +395,8 @@ on_window_keyboard_delete_event (GtkWidget * widget, GdkEvent * event, gpointer
  */
 void
 on_entry_kb_main_insert_text (GtkEditable * editable,
-			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
+			      gchar * new_text, gint new_text_length, gpointer position,
+			      gpointer user_data)
 {
 	gchar *tmp_str;
 
@@ -351,7 +418,8 @@ on_entry_kb_main_insert_text (GtkEditable * editable,
  */
 void
 on_entry_kb_user_insert_text (GtkEditable * editable,
-			      gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
+			      gchar * new_text, gint new_text_length, gpointer position,
+			      gpointer user_data)
 {
 	gchar *tmp_str;
 
@@ -394,7 +462,8 @@ on_button_kb_save_clicked (GtkButton * button, gpointer user_data)
 			fclose (fh);
 			dialog_confirm = create_dialog_confirm ();
 			gtk_label_set_text (GTK_LABEL (lookup_widget
-						       (dialog_confirm, "label_confirm_action")), "OVERWRITE");
+						       (dialog_confirm, "label_confirm_action")),
+					    "OVERWRITE");
 			gtk_widget_show (dialog_confirm);
 			return;
 		}
@@ -432,7 +501,8 @@ on_button_kb_remove_clicked (GtkButton * button, gpointer user_data)
 	g_free (tmp_keyb);
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "REMOVE");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")),
+			    "REMOVE");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -478,7 +548,8 @@ on_button_keyboard_cancel_clicked (GtkButton * button, gpointer user_data)
  * Allowing or not to select "load" tab on notebook
  */
 void
-on_notebook_kb_switch_page (GtkNotebook * notebook, GtkNotebookPage * page, guint page_num, gpointer user_data)
+on_notebook_kb_switch_page (GtkNotebook * notebook, GtkNotebookPage * page, guint page_num,
+			    gpointer user_data)
 {
 	if (keyb_get_modified_status () == FALSE)
 		return;
@@ -554,7 +625,8 @@ on_button_keyboard_close_clicked (GtkButton * button, gpointer user_data)
  */
 void
 on_entry_popup_key_insert_text (GtkEditable * editable,
-				gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
+				gchar * new_text, gint new_text_length, gpointer position,
+				gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
@@ -597,6 +669,9 @@ on_window_tutor_destroy (GtkObject * object, gpointer user_data)
 	if (GTK_IS_WIDGET (window_hints_))
 		gtk_widget_destroy (window_hints_);
 
+	if (GTK_IS_WIDGET (window_top10_))
+		gtk_widget_hide (window_top10_);
+
 	if (GTK_IS_WIDGET (filechooser_tutor))
 		gtk_widget_destroy (filechooser_tutor);
 
@@ -626,14 +701,18 @@ on_text_tutor_realize (GtkWidget * widget, gpointer user_data)
 	gtk_text_buffer_create_tag (buf, "char_untouched",
 				    "background", TUTOR_GRAY_BLUE, "foreground", TUTOR_BLACK, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_wrong", "background", TUTOR_RED, "foreground", TUTOR_BLACK, NULL);
+	gtk_text_buffer_create_tag (buf, "char_wrong", "background", TUTOR_RED, "foreground",
+				    TUTOR_BLACK, NULL);
 
-	gtk_text_buffer_create_tag (buf, "char_correct", "background", TUTOR_GREEN, "foreground", TUTOR_BLACK, NULL);
+	gtk_text_buffer_create_tag (buf, "char_correct", "background", TUTOR_GREEN, "foreground",
+				    TUTOR_BLACK, NULL);
 
 	gtk_text_buffer_create_tag (buf, "char_retouched",
-				    "background", TUTOR_YELLOW_GREEN, "foreground", TUTOR_BLACK, NULL);
+				    "background", TUTOR_YELLOW_GREEN, "foreground", TUTOR_BLACK,
+				    NULL);
 
-	gtk_text_buffer_create_tag (buf, "cursor_blink", "background", TUTOR_BLACK, "foreground", TUTOR_WHITE, NULL);
+	gtk_text_buffer_create_tag (buf, "cursor_blink", "background", TUTOR_BLACK, "foreground",
+				    TUTOR_WHITE, NULL);
 
 	tmp_font = main_preferences_get_string ("tutor", "lesson_font");
 	if (tmp_font == NULL)
@@ -722,7 +801,8 @@ on_button_reset_lesson_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dialog_confirm;
 
 	dialog_confirm = create_dialog_confirm ();
-	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")), "RESET");
+	gtk_label_set_text (GTK_LABEL (lookup_widget (dialog_confirm, "label_confirm_action")),
+			    "RESET");
 	gtk_widget_show (dialog_confirm);
 }
 
@@ -766,11 +846,22 @@ on_button_tutor_stat_clicked (GtkButton * button, gpointer user_data)
 	case TT_FLUID:
 		gtk_label_set_text (label_stat, _("fluidness exercises"));
 		gtk_widget_show (lookup_widget (window_stat_, "toggle_stat_fluid"));
+		gtk_widget_show (lookup_widget (window_stat_, "toggle_stat_score"));
 	}
 
 	gtk_widget_show (window_stat_);
 }
 
+/**********************************************************************
+ * Show Top 10 scores
+ */
+void
+on_button_tutor_top10_clicked (GtkButton * button, gpointer user_data)
+{
+	top10_show_stats (GLOBAL);
+	top10_show_stats (LOCAL);
+}
+
 
 /**********************************************************************
  * Show the helping virtual keyboard
@@ -788,7 +879,8 @@ on_button_tutor_show_keyb_clicked (GtkButton * button, gpointer user_data)
 	gtk_window_set_title (GTK_WINDOW (window_keyboard_), _("Virtual Keyboard"));
 	gtk_label_set_text (GTK_LABEL
 			    (lookup_widget
-			     (window_keyboard_, "label_virtual_kb")), _("Relation between the fingers and the keys"));
+			     (window_keyboard_, "label_virtual_kb")),
+			    _("Relation between the fingers and the keys"));
 
 	keyb_update_virtual_layout ();
 	hints_init ();
@@ -912,7 +1004,9 @@ on_fontselectiondialog_tutor_response (GtkDialog * dialog, gint response_id, gpo
 	if (response_id == GTK_RESPONSE_CANCEL)
 		tmp_font = main_preferences_get_string ("tutor", "lesson_font");
 	else
-		tmp_font = g_strdup (gtk_font_selection_dialog_get_font_name (GTK_FONT_SELECTION_DIALOG (dialog)));
+		tmp_font =
+			g_strdup (gtk_font_selection_dialog_get_font_name
+				  (GTK_FONT_SELECTION_DIALOG (dialog)));
 
 	if (tmp_font == NULL)
 		tmp_font = g_strdup (LESSON_FONT);
@@ -1019,14 +1113,42 @@ on_entry_mesg_delete_text (GtkEditable * editable, gint start_pos, gint end_pos,
 
 void
 on_entry_mesg_insert_text (GtkEditable * editable,
-			   gchar * new_text, gint new_text_length, gpointer position, gpointer user_data)
+			   gchar * new_text, gint new_text_length, gpointer position,
+			   gpointer user_data)
 {
 	if (callbacks_shield)
 		return;
+	if (mesg_drag_drop)
+	{
+		mesg_drag_drop = FALSE;
+
+		callbacks_shield = TRUE;
+		gtk_editable_delete_text (editable, 0, -1);
+		callbacks_shield = FALSE;
+
+		if (tutor_get_type () == TT_VELO)
+			velo_text_write_to_file (new_text, TRUE);
+		else if (tutor_get_type () == TT_FLUID)
+			fluid_text_write_to_file (new_text);
+		return;
+	}
 
 	tutor_process_touch (g_utf8_get_char_validated (new_text, new_text_length));
 }
 
+/* Tutor drag and drop handling
+ */
+gboolean
+on_entry_mesg_drag_drop (GtkWidget * widget, GdkDragContext * drag_context,
+			 gint x, gint y, guint time, gpointer user_data)
+{
+	callbacks_shield = TRUE;
+	gtk_entry_set_text (GTK_ENTRY (widget), "");
+	callbacks_shield = FALSE;
+	mesg_drag_drop = TRUE;
+	return FALSE;
+}
+
 
 /**********************************************************************
  * Controlling the restart action during the exercises
@@ -1050,31 +1172,6 @@ on_button_tutor_restart_clicked (GtkButton * button, gpointer user_data)
 /**********************************************************************
  * Popup management
  */
-gboolean
-on_popup_other_enter_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data)
-{
-	if (callbacks_shield)
-	{
-		callbacks_shield = FALSE;
-		return FALSE;
-	}
-
-	gtk_widget_destroy (widget);
-	return FALSE;
-}
-
-
-gboolean
-on_popup_other_leave_notify_event (GtkWidget * widget, GdkEventCrossing * event, gpointer user_data)
-{
-	if (callbacks_shield)
-		return FALSE;
-
-	gtk_widget_destroy (widget);
-	return FALSE;
-}
-
-
 void
 on_treeview_other_realize (GtkWidget * widget, gpointer user_data)
 {
@@ -1106,7 +1203,11 @@ on_treeview_other_destroy (GtkObject * object, gpointer user_data)
 
 	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (object));
 	if (gtk_tree_selection_get_selected (sel, &store, &iter) == FALSE)
+	{
+		tutor_set_query (QUERY_INTRO);
+		tutor_process_touch ('\0');
 		return;
+	}
 
 	gtk_tree_model_get (store, &iter, 0, &tmp_name, -1);
 
@@ -1140,6 +1241,38 @@ on_button_other_new_clicked (GtkButton * button, gpointer user_data)
 	gtk_widget_show (filechooser_tutor);
 }
 
+/**********************************************************************
+ * Paste copied text as an exercise
+ */
+void
+on_button_other_paste_clicked (GtkButton * button, gpointer user_data)
+{
+	gchar *text;
+
+	if (clipboard == NULL)
+		clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+	if (clipboard_2 == NULL)
+		clipboard_2 = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
+
+	text = gtk_clipboard_wait_for_text (clipboard);
+	if (text == NULL)
+		text = gtk_clipboard_wait_for_text (clipboard_2);
+	if (text == NULL)
+	{
+		gdk_beep ();
+		g_message ("No text in the Clipboard");
+		return;
+	}
+
+	if (tutor_get_type () == TT_VELO)
+		velo_text_write_to_file (text, TRUE);
+	else if (tutor_get_type () == TT_FLUID)
+		fluid_text_write_to_file (text);
+	g_free (text);
+
+	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
+}
+
 
 /**********************************************************************
  * Remove some user exercise
@@ -1227,102 +1360,41 @@ on_frame_stat_realize (GtkWidget * widget, gpointer user_data)
 	plot_initialize (widget);
 }
 
-
-/**********************************************************************
- * Show accuracy chart
+/* Show accuracy chart
  */
 void
 on_toggle_stat_accur_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
-	GtkWidget *wg;
-
-	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_velo");
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_fluid");
-		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-		{
-			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton, TRUE);
-			return;
-		}
-		else if (!gtk_toggle_button_get_active (togglebutton))
-			return;
-		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-	}
-	else if (!gtk_toggle_button_get_active (togglebutton))
-		return;
-	else
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-
-	plot_draw_chart (1);
+	if (gtk_toggle_button_get_active (togglebutton))
+		plot_draw_chart (1);
 }
 
-
-/**********************************************************************
- * Show velocity chart
+/* Show velocity chart
  */
 void
 on_toggle_stat_velo_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
-	GtkWidget *wg;
-
-	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_accur");
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_fluid");
-		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-		{
-			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton, TRUE);
-			return;
-		}
-		else if (!gtk_toggle_button_get_active (togglebutton))
-			return;
-		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-	}
-	else if (!gtk_toggle_button_get_active (togglebutton))
-		return;
-	else
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-
-	plot_draw_chart (2);
+	if (gtk_toggle_button_get_active (togglebutton))
+		plot_draw_chart (2);
 }
 
-
-/**********************************************************************
- * Show fluidness chart
+/* Show fluidness chart
  */
 void
 on_toggle_stat_fluid_toggled (GtkToggleButton * togglebutton, gpointer user_data)
 {
-	GtkWidget *wg;
-
-	wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_accur");
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-	{
-		wg = lookup_widget (GTK_WIDGET (togglebutton), "toggle_stat_velo");
-		if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
-		{
-			if (!gtk_toggle_button_get_active (togglebutton))
-				gtk_toggle_button_set_active (togglebutton, TRUE);
-			return;
-		}
-		else if (!gtk_toggle_button_get_active (togglebutton))
-			return;
-		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-	}
-	else if (!gtk_toggle_button_get_active (togglebutton))
-		return;
-	else
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
-
-	plot_draw_chart (3);
+	if (gtk_toggle_button_get_active (togglebutton))
+		plot_draw_chart (3);
 }
 
+/* Show scorings chart
+ */
+void
+on_toggle_stat_score_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	if (gtk_toggle_button_get_active (togglebutton))
+		plot_draw_chart (4);
+}
 
 /*
  * Closing the progress window
@@ -1333,7 +1405,203 @@ on_button_stat_close_clicked (GtkButton * button, gpointer user_data)
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
 }
 
+/**********************************************************************
+ * Part 6
+ * Top 10 management
+ */
+void
+on_togglebutton_top10_local_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	top10_show_stats (LOCAL);
+}
 
+void
+on_button_top10_exclude_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *wg;
+
+	wg = lookup_widget (window_top10_, "checkbutton_top10_exclude");
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (wg)))
+	{
+		top10_delete_stat (0, LOCAL);
+		top10_write_stats (LOCAL, -1);
+		top10_show_stats (LOCAL);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
+	}
+	else
+		gdk_beep ();
+}
+
+void
+on_togglebutton_top10_external_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	top10_show_stats (GLOBAL);
+}
+
+void
+on_button_top10_update_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *wg;
+
+	wg = lookup_widget (window_top10_, "image_top10_update");
+	gtk_image_set_from_stock (GTK_IMAGE (wg), "gtk-yes", GTK_ICON_SIZE_BUTTON);
+	wg = lookup_widget (window_top10_, "notebook_top10");
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (wg), 1);
+	g_idle_add ((GSourceFunc) top10_global_update, NULL);
+}
+
+void
+on_button_top10_publish_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *wg;
+
+	wg = lookup_widget (window_top10_, "image_top10_publish");
+	gtk_image_set_from_stock (GTK_IMAGE (wg), "gtk-yes", GTK_ICON_SIZE_BUTTON);
+	wg = lookup_widget (window_top10_, "notebook_top10");
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (wg), 1);
+	g_idle_add ((GSourceFunc) top10_global_publish, NULL);
+}
+
+void
+on_checkbutton_top10_default_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	GtkWidget *wg;
+	gboolean toggle;
+
+	toggle = gtk_toggle_button_get_active (togglebutton);
+
+	wg = lookup_widget (window_top10_, "checkbutton_top10_manager");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
+
+	wg = lookup_widget (window_top10_, "checkbutton_top10_personal");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
+
+	wg = lookup_widget (window_top10_, "frame_top10_personal");
+	gtk_widget_set_sensitive (wg, !toggle);
+
+	main_preferences_set_boolean ("game", "default", toggle);
+}
+
+void
+on_checkbutton_top10_personal_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	GtkWidget *wg;
+	gboolean toggle;
+
+	wg = lookup_widget (window_top10_, "checkbutton_top10_manager");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (wg), FALSE);
+
+	toggle = gtk_toggle_button_get_active (togglebutton);
+
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_uphost"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_upuser"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_uppass"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_downhost"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_uphost"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_upuser"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_uppass"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_downhost"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "frame_top10_manager"), toggle);
+
+	main_preferences_set_boolean ("game", "personal", toggle);
+}
+
+void
+on_checkbutton_top10_manager_toggled (GtkToggleButton * togglebutton, gpointer user_data)
+{
+	gboolean toggle;
+
+	toggle = gtk_toggle_button_get_active (togglebutton);
+
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_downuser"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "label_top10_downpass"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_downuser"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "entry_top10_downpass"), toggle);
+	gtk_widget_set_sensitive (lookup_widget (window_top10_, "button_top10_downupdate"), toggle);
+
+	main_preferences_set_boolean ("game", "manager", toggle);
+}
+
+void
+on_entry_top10_uphost_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "uphost",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_entry_top10_upuser_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "upuser",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_entry_top10_uppass_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "uppass",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_entry_top10_downhost_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "downhost",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_entry_top10_downuser_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "downuser",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_entry_top10_downpass_changed (GtkEditable * editable, gpointer user_data)
+{
+	main_preferences_set_string ("game", "downpass",
+				     (gchar *) gtk_entry_get_text (GTK_ENTRY (editable)));
+}
+
+void
+on_button_top10_downupdate_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *wg;
+
+	wg = lookup_widget (window_top10_, "notebook_top10");
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (wg), 1);
+
+	top10_global_rank ();
+	top10_show_stats (GLOBAL);
+}
+
+void
+on_button_top10_host_test_clicked (GtkButton * button, gpointer user_data)
+{
+	GtkWidget *wg;
+
+	wg = lookup_widget (window_top10_, "notebook_top10");
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (wg), 1);
+	g_idle_add ((GSourceFunc) top10_host_test, NULL);
+}
+
+void
+on_button_top10_close_clicked (GtkButton * button, gpointer user_data)
+{
+	gtk_widget_hide (window_top10_);
+}
+
+void
+on_window_top10_destroy (GtkObject * object, gpointer user_data)
+{
+	window_top10_ = NULL;
+}
+
+/**********************************************************************
+ * Part 7
+ * Callbacks for other tasks
+ */
 /**********************************************************************
  * Confirm-dialog shared tasks
  */
@@ -1355,7 +1623,8 @@ on_dialog_confirm_realize (GtkWidget * widget, gpointer user_data)
 	else if (strcmp (action, "OVERWRITE") == 0)
 	{
 		gtk_window_set_title (GTK_WINDOW (widget), _("Overwrite user layout"));
-		gtk_label_set_text (wg_label, _("This will OVERWRITE an existent keyboard layout."));
+		gtk_label_set_text (wg_label,
+				    _("This will OVERWRITE an existent keyboard layout."));
 	}
 
 	else if (strcmp (action, "REMOVE") == 0)
@@ -1417,7 +1686,6 @@ on_button_confirm_yes_clicked (GtkButton * button, gpointer user_data)
 	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
 }
 
-
 void
 on_button_confirm_no_clicked (GtkButton * button, gpointer user_data)
 {
