@@ -20,6 +20,7 @@
 #include "support.h"
 #include "main.h"
 #include "translation.h"
+#include "keyboard.h"
 #include "tutor.h"
 #include "velocity.h"
 #include "fluidness.h"
@@ -110,7 +111,8 @@ fluid_init ()
 		main_preferences_set_int ("tutor", "fluid_paragraphs", 3);
 
 	wg = lookup_widget (window_tutor_, "spinbutton_lesson");
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON (wg), main_preferences_get_int ("tutor", "fluid_paragraphs"));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (wg),
+				   main_preferences_get_int ("tutor", "fluid_paragraphs"));
 
 	if (par.len == 0)
 	{
@@ -244,6 +246,166 @@ fluid_draw_random_paragraphs ()
 	}
 }
 
+/**********************************************************************
+ * Takes text and validate it as UTF-8
+ */
+gchar *
+fluid_filter_utf8 (gchar * text)
+{
+	gulong i;
+	gunichar uch = 0;
+	gboolean is_symbol;
+	struct INPUT_TEXT
+	{
+		gchar *pt;
+		gulong len;
+		guint npar;
+	} raw;
+	struct KEYBOARD_SYMBOLS
+	{
+		gunichar set[200];
+		guint n;
+	} sym;
+	struct FILTERED_TEXT
+	{
+		gchar *txt;
+		gulong i;
+		gulong len;
+	} flt;
+
+	raw.len = strlen (text);
+
+	/* Verify empty input string
+	 */
+	if (raw.len == 0)
+	{
+		flt.txt = g_strdup_printf ("%i.\n", rand () % 9000);
+		return (flt.txt);
+	}
+
+	/* Allocate memory space for the result
+	 */
+	flt.i = 0;
+	flt.len = raw.len + 100;
+	flt.txt = g_malloc (flt.len);
+
+	/* By-pass BOM
+	 */
+	raw.pt = text;
+	if (g_utf8_get_char_validated (raw.pt, 16) == 0xEFBBBF)
+		raw.pt = g_utf8_find_next_char (raw.pt, raw.pt + 16);
+
+	/* Replace Win/MAC-returns
+	 */
+	for (i = 0; i < raw.len; i++)
+		if (text[i] == '\r')
+			text[i] = '\n';
+
+	/* Filter
+	 */
+	sym.n = keyb_get_symbols (sym.set);
+	raw.npar = 0;
+	while (raw.pt && raw.npar < MAX_PARAGRAPHS)
+	{
+		if (*raw.pt == '\0')
+			break;
+		/* Test valid utf8 char
+		 */
+		if ((uch = g_utf8_get_char_validated (raw.pt, 16)) == (gunichar) - 1
+		    || uch == (gunichar) - 2)
+			uch = L' ';
+
+		/* Increase the pointer for the input text
+		 */
+		raw.pt = g_utf8_find_next_char (raw.pt, raw.pt + 16);
+
+		/* Test reazonable char as valid for fluidness exercise
+		 */
+		if (!(uch == L' ' || uch == L'\n' || g_unichar_isalnum (uch)))
+		{
+			is_symbol = FALSE;
+			for (i = 0; i < sym.n; i++)
+				if (uch == sym.set[i])
+				{
+					is_symbol = TRUE;
+					break;
+				}
+			if (!is_symbol)
+				uch = L' ';
+		}
+
+		/* Verify memory space of output buffer
+		 */
+		if (flt.i < flt.len - 7)
+		{
+			flt.len += 100;
+			flt.txt = g_realloc (flt.txt, flt.len);
+		}
+
+		/* Verify new line and form the next UTF-8 char to be appended
+		 */
+		if (uch == L'\n')
+		{
+			raw.npar++;
+			flt.txt[flt.i++] = '\n';
+			flt.txt[flt.i++] = '\n';
+			for (; *raw.pt == '\n' || *raw.pt == ' '; raw.pt++);
+		}
+		else
+			flt.i += g_unichar_to_utf8 (uch, &flt.txt[flt.i]);
+	}
+	if (uch != L'\n')
+	{
+		raw.npar++;
+		flt.txt[flt.i++] = '\n';
+		flt.txt[flt.i++] = '\n';
+	}
+	flt.txt[flt.i++] = '\0';
+
+	return (flt.txt);
+}
+
+/**********************************************************************
+ * Paste clipboard or dropped text in a file, so that it can be used as
+ * a customized exercise.
+ */
+void
+fluid_text_write_to_file (gchar * text_raw)
+{
+	gchar *pars_path;
+	gchar *pars_name;
+	gchar *text_filtered;
+	FILE *fh_destiny;
+
+	pars_name = g_strdup (_("Pasted_or_dropped"));
+	pars_path = g_strconcat (main_get_user_dir (), pars_name, ".paragraphs", NULL);
+	assert_user_dir ();
+	if (!(fh_destiny = (FILE *) g_fopen (pars_path, "w")))
+	{
+		gdk_beep ();
+		g_warning ("couldn't create the file:\n %s", pars_path);
+		g_free (pars_path);
+		g_free (pars_name);
+		return;
+	}
+	g_free (pars_path);
+
+	/* Filter the text
+	 */
+	text_filtered = fluid_filter_utf8 (text_raw);
+	fwrite (text_filtered, sizeof (gchar), strlen (text_filtered), fh_destiny);
+	fclose (fh_destiny);
+
+	g_free (text_filtered);
+
+	fluid_init_paragraph_list (pars_name);
+	g_free (pars_name);
+	tutor_set_query (QUERY_INTRO);
+	tutor_process_touch ('\0');
+
+	velo_text_write_to_file (text_raw, FALSE);
+}
+
 /**********************************************************************
  * Copy the file 'file_name' so that it can be used as a customized
  * exercise.
@@ -251,13 +413,10 @@ fluid_draw_random_paragraphs ()
 void
 fluid_copy_text_file (gchar * file_name)
 {
-	gchar tmp_str[MAX_PAR_LEN];
-	gint nlin;
-	gboolean empty_file;
-	gchar *tab;
 	gchar *pars_path;
 	gchar *pars_name;
-	FILE *fh_source;
+	gchar *text_raw;
+	gchar *text_filtered;
 	FILE *fh_destiny;
 
 	if (!file_name)
@@ -267,77 +426,41 @@ fluid_copy_text_file (gchar * file_name)
 		return;
 	}
 
-	if (!(fh_source = (FILE *) g_fopen (file_name, "r")))
+	if (!g_file_get_contents (file_name, &text_raw, NULL, NULL))
 	{
 		gdk_beep ();
-		g_warning ("couldn't open the file:\n %s\n", file_name);
+		g_warning ("couldn't read the file:\n %s\n", file_name);
 		return;
 	}
 
 	pars_name = g_strdup (strrchr (file_name, DIRSEP) + 1);
 	pars_path = g_strconcat (main_get_user_dir (), pars_name, ".paragraphs", NULL);
-
 	assert_user_dir ();
 	if (!(fh_destiny = (FILE *) g_fopen (pars_path, "w")))
 	{
 		gdk_beep ();
-		g_warning ("couldn't create the file:\n %s\n", pars_path);
-		fclose (fh_source);
+		g_warning ("couldn't create the file:\n %s", pars_path);
 		g_free (pars_path);
 		g_free (pars_name);
 		return;
 	}
 	g_free (pars_path);
 
-	/********************
-	 * Process the file
+	/* Filter the text
 	 */
-	empty_file = TRUE;
-	nlin = 0;
-	//g_print ("Processing file:\n %s\nParagraphs:\n0", file_name);
-	while (fgets (tmp_str, MAX_PAR_LEN, fh_source) != NULL)
-	{
-		if (nlin++ > MAX_PARAGRAPHS)
-		{
-			//g_print (" - truncated!");
-			break;
-		}
-		g_print (" - %u", nlin);
-
-		if (g_utf8_validate (tmp_str, -1, NULL) == FALSE)
-		{
-			//g_print (": NOT UTF8!");
-			continue;
-		}
-		if (strcmp (tmp_str, "\n") == 0)
-		{
-			//g_print (": BLANK!");
-			continue;
-		}
-
-		tab = tmp_str;
-		while ((tab = strchr (tab, '\t')))
-			*tab = ' ';
-
-		fputs (tmp_str, fh_destiny);
-		empty_file = FALSE;
-	}
-	if (empty_file)
-		fprintf (fh_destiny, "%i.\n", rand () % 9000);
-	else if (tmp_str[strlen (tmp_str) - 1] != '\n')
-		fputc ('\n', fh_destiny);
-
-	fclose (fh_source);
+	text_filtered = fluid_filter_utf8 (text_raw);
+	fwrite (text_filtered, sizeof (gchar), strlen (text_filtered), fh_destiny);
 	fclose (fh_destiny);
 
-	//g_print (" - end.\n");
+	g_free (text_raw);
+	g_free (text_filtered);
 
 	fluid_init_paragraph_list (pars_name);
+	g_free (pars_name);
 	tutor_set_query (QUERY_INTRO);
 	tutor_process_touch ('\0');
 
 	velo_create_dict (file_name, FALSE);
-	g_free (pars_name);
 }
 
 /**********************************************************************
@@ -354,15 +477,21 @@ fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness)
 	 * Comments
 	 */
 	if (accuracy < 98)
-		tmp_str = g_strdup (_(" Your accuracy rate is too low.\n" " I want it greater than 98 %%.\n"));
+		tmp_str =
+			g_strdup (_
+				  (" Your accuracy rate is too low.\n"
+				   " I want it greater than 98 %.\n"));
 	else if (velocity < 50)
-		tmp_str = g_strdup (_(" You type accurately but not fast.\n" " Can you reach 50 WPM?\n"));
+		tmp_str =
+			g_strdup (_
+				  (" You type accurately but not fast.\n"
+				   " Can you reach 50 WPM?\n"));
 	else if (fluidness < 70)
 		tmp_str = g_strdup (_(" Your rhythm is not so constant. Calm down.\n"
-				      " For now, try to make the fluidness greater than 70 %%.\n"));
-	else if (fluidness < 90)
+				      " For now, try to make the fluidness greater than 70 %.\n"));
+	else if (fluidness < 80)
 		tmp_str = g_strdup (_(" You are almost getting there. Type more fluently.\n"
-				      " I want a fluidness greater than 90 %%.\n"));
+				      " I want a fluidness greater than 80 %.\n"));
 	else if (velocity < 80)
 		tmp_str = g_strdup (_(" Congratulations!\n"
 				      " It seems to me that you are a professional.\n"
