@@ -28,6 +28,10 @@ void fluid_init_paragraph_list (gchar * list_name);
 
 void fluid_draw_random_paragraphs (void);
 
+gchar *fluid_filter_utf8 (gchar * text);
+
+void fluid_text_write_to_file (gchar * text_raw);
+
 void fluid_copy_text_file (gchar * file_name);
 
 void fluid_comment (gdouble accuracy, gdouble velocity, gdouble fluidness);
