@@ -96,10 +96,13 @@ static void gtk_databox_zoomed (GtkWidget * widget, GtkDatabox * box, gboolean r
 static void gtk_databox_adj_x_changed (GtkAdjustment * adjX, GtkDatabox * box);
 static void gtk_databox_adj_y_changed (GtkAdjustment * adjY, GtkDatabox * box);
 static gint gtk_databox_button_press (GtkWidget * widget, GdkEventButton * event, GtkDatabox * box);
-static gint gtk_databox_button_release (GtkWidget * widget, GdkEventButton * event, GtkDatabox * box);
-static gint gtk_databox_motion_notify (GtkWidget * widget, GdkEventMotion * event, GtkDatabox * box);
+static gint gtk_databox_button_release (GtkWidget * widget, GdkEventButton * event,
+					GtkDatabox * box);
+static gint gtk_databox_motion_notify (GtkWidget * widget, GdkEventMotion * event,
+				       GtkDatabox * box);
 static void gtk_databox_draw_request (GtkDatabox * box);
-static void gtk_databox_draw_selection (GtkWidget * widget, GtkDatabox * box, GdkRectangle * pixmapCopyRect);
+static void gtk_databox_draw_selection (GtkWidget * widget, GtkDatabox * box,
+					GdkRectangle * pixmapCopyRect);
 static void gtk_databox_draw (GtkWidget * widget, GtkDatabox * box, GdkEventExpose * event);
 static void gtk_databox_draw_points (GtkDatabox * box, GtkDataboxData * data);
 static void gtk_databox_draw_lines (GtkDatabox * box, GtkDataboxData * data);
@@ -109,11 +112,13 @@ static void gtk_databox_draw_grid (GtkDatabox * box, GtkDataboxData * data);
 static void gtk_databox_data_gc_new (GtkWidget * widget, GtkDatabox * box, GtkDataboxData * data);
 static void gtk_databox_ruler_x_update (GtkDatabox * box);
 static void gtk_databox_ruler_y_update (GtkDatabox * box);
-static void gtk_databox_data_calc_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDataboxValue * max);
+static void gtk_databox_data_calc_extrema (GtkDatabox * box, GtkDataboxValue * min,
+					   GtkDataboxValue * max);
 static gint gtk_databox_data_check_x_links (GList * list, gfloat * values);
 static gint gtk_databox_data_check_y_links (GList * list, gfloat * values);
 static void gtk_databox_data_destroy_internal (GtkDatabox * box,
-					       GtkDataboxData * data, GList * list, gboolean free_flag);
+					       GtkDataboxData * data, GList * list,
+					       gboolean free_flag);
 static gint gtk_databox_data_destroy_with_flag (GtkDatabox * box, gint index, gboolean free_flag);
 static gint gtk_databox_data_destroy_with_flag_all (GtkDatabox * box, gboolean free_flag);
 enum
@@ -150,7 +155,8 @@ gtk_databox_get_type ()
 			(GInstanceInitFunc) gtk_databox_init,
 		};
 
-		databox_type = g_type_register_static (GTK_TYPE_VBOX, "GtkDatabox", &databox_info, 0);
+		databox_type =
+			g_type_register_static (GTK_TYPE_VBOX, "GtkDatabox", &databox_info, 0);
 	}
 
 	return databox_type;
@@ -180,25 +186,31 @@ gtk_databox_class_init (GtkDataboxClass * klass)
 	gtk_databox_signals[GTK_DATABOX_ZOOMED_SIGNAL] = g_signal_new ("gtk_databox_zoomed", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_zoomed), NULL,	/* accumulator */
 								       NULL,	/* accumulator_data */
 								       gtk_databox_marshal_VOID__POINTER_POINTER,
-								       G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_POINTER);
+								       G_TYPE_NONE, 2,
+								       G_TYPE_POINTER,
+								       G_TYPE_POINTER);
 	gtk_databox_signals[GTK_DATABOX_MARKED_SIGNAL] = g_signal_new ("gtk_databox_marked", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_marked), NULL,	/* accumulator */
 								       NULL,	/* accumulator_data */
 								       gtk_databox_marshal_VOID__POINTER,
-								       G_TYPE_NONE, 1, G_TYPE_POINTER);
+								       G_TYPE_NONE, 1,
+								       G_TYPE_POINTER);
 	gtk_databox_signals[GTK_DATABOX_SELECTION_STARTED_SIGNAL] = g_signal_new ("gtk_databox_selection_started", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_selection_started), NULL,	/* accumulator */
 										  NULL,	/* accumulator_data */
 										  gtk_databox_marshal_VOID__POINTER,
-										  G_TYPE_NONE, 1, G_TYPE_POINTER);
+										  G_TYPE_NONE, 1,
+										  G_TYPE_POINTER);
 	gtk_databox_signals[GTK_DATABOX_SELECTION_CHANGED_SIGNAL] = g_signal_new ("gtk_databox_selection_changed", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_selection_changed), NULL,	/* accumulator */
 										  NULL,	/* accumulator_data */
 										  gtk_databox_marshal_VOID__POINTER_POINTER,
 										  G_TYPE_NONE,
-										  2, G_TYPE_POINTER, G_TYPE_POINTER);
+										  2, G_TYPE_POINTER,
+										  G_TYPE_POINTER);
 	gtk_databox_signals[GTK_DATABOX_SELECTION_STOPPED_SIGNAL] = g_signal_new ("gtk_databox_selection_stopped", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_selection_stopped), NULL,	/* accumulator */
 										  NULL,	/* accumulator_data */
 										  gtk_databox_marshal_VOID__POINTER_POINTER,
 										  G_TYPE_NONE,
-										  2, G_TYPE_POINTER, G_TYPE_POINTER);
+										  2, G_TYPE_POINTER,
+										  G_TYPE_POINTER);
 	gtk_databox_signals[GTK_DATABOX_SELECTION_CANCELLED_SIGNAL] = g_signal_new ("gtk_databox_selection_cancelled", G_TYPE_FROM_CLASS (object_class), G_SIGNAL_RUN_FIRST, G_STRUCT_OFFSET (GtkDataboxClass, gtk_databox_selection_cancelled), NULL,	/* accumulator */
 										    NULL,	/* accumulator_data */
 										    gtk_databox_marshal_VOID__VOID,
@@ -226,17 +238,23 @@ gtk_databox_init (GtkDatabox * box)
 	gtk_widget_set_events (widget,
 			       GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
 			       | GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK);
-	g_signal_connect (GTK_OBJECT (widget), "destroy", GTK_SIGNAL_FUNC (gtk_databox_destroy), box);
-	g_signal_connect (GTK_OBJECT (widget), "configure_event", GTK_SIGNAL_FUNC (gtk_databox_configure), box);
-	g_signal_connect (GTK_OBJECT (widget), "expose_event", GTK_SIGNAL_FUNC (gtk_databox_expose), box);
-	g_signal_connect (GTK_OBJECT (widget), "button_press_event", GTK_SIGNAL_FUNC (gtk_databox_button_press), box);
+	g_signal_connect (GTK_OBJECT (widget), "destroy", GTK_SIGNAL_FUNC (gtk_databox_destroy),
+			  box);
+	g_signal_connect (GTK_OBJECT (widget), "configure_event",
+			  GTK_SIGNAL_FUNC (gtk_databox_configure), box);
+	g_signal_connect (GTK_OBJECT (widget), "expose_event", GTK_SIGNAL_FUNC (gtk_databox_expose),
+			  box);
+	g_signal_connect (GTK_OBJECT (widget), "button_press_event",
+			  GTK_SIGNAL_FUNC (gtk_databox_button_press), box);
 	g_signal_connect (GTK_OBJECT (widget), "button_release_event",
 			  GTK_SIGNAL_FUNC (gtk_databox_button_release), box);
-	g_signal_connect (GTK_OBJECT (widget), "motion_notify_event", GTK_SIGNAL_FUNC (gtk_databox_motion_notify), box);
+	g_signal_connect (GTK_OBJECT (widget), "motion_notify_event",
+			  GTK_SIGNAL_FUNC (gtk_databox_motion_notify), box);
 	gtk_widget_set_size_request (widget, 20, 30);
 
 	gtk_table_attach (GTK_TABLE (box->table), widget, 1, 2, 1, 2,
-			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
+			  GTK_FILL | GTK_EXPAND | GTK_SHRINK, GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0,
+			  0);
 	gtk_widget_show (widget);
 
 	box->adjX = GTK_ADJUSTMENT (gtk_adjustment_new (0.0, 0.0, 1.0, 0.1, 0.9, 1.0));
@@ -244,8 +262,10 @@ gtk_databox_init (GtkDatabox * box)
 	g_object_ref (GTK_OBJECT (box->adjX));
 	g_object_ref (GTK_OBJECT (box->adjY));
 
-	g_signal_connect (GTK_OBJECT (box->adjY), "value_changed", GTK_SIGNAL_FUNC (gtk_databox_adj_y_changed), box);
-	g_signal_connect (GTK_OBJECT (box->adjX), "value_changed", GTK_SIGNAL_FUNC (gtk_databox_adj_x_changed), box);
+	g_signal_connect (GTK_OBJECT (box->adjY), "value_changed",
+			  GTK_SIGNAL_FUNC (gtk_databox_adj_y_changed), box);
+	g_signal_connect (GTK_OBJECT (box->adjX), "value_changed",
+			  GTK_SIGNAL_FUNC (gtk_databox_adj_x_changed), box);
 
 	box->flags = 0;
 
@@ -294,7 +314,8 @@ gtk_databox_set_rulers_enable (GtkDatabox * box, gboolean enable)
 					  g_cclosure_new_object_swap
 					  (GTK_SIGNAL_FUNC
 					   (GTK_WIDGET_GET_CLASS
-					    (box->rulerX)->motion_notify_event), G_OBJECT (box->rulerX)), FALSE);
+					    (box->rulerX)->motion_notify_event),
+					   G_OBJECT (box->rulerX)), FALSE);
 		box->rulerY = gtk_vruler_new ();
 		gtk_ruler_set_metric (GTK_RULER (box->rulerY), GTK_PIXELS);
 		gtk_databox_ruler_y_update (box);
@@ -302,7 +323,8 @@ gtk_databox_set_rulers_enable (GtkDatabox * box, gboolean enable)
 					  g_cclosure_new_object_swap
 					  (GTK_SIGNAL_FUNC
 					   (GTK_WIDGET_GET_CLASS
-					    (box->rulerY)->motion_notify_event), G_OBJECT (box->rulerY)), FALSE);
+					    (box->rulerY)->motion_notify_event),
+					   G_OBJECT (box->rulerY)), FALSE);
 
 		gtk_table_attach (GTK_TABLE (box->table), box->rulerX, 1, 2,
 				  0, 1, GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_FILL, 0, 0);
@@ -492,7 +514,8 @@ gtk_databox_configure (GtkWidget * widget, GdkEventConfigure * event, GtkDatabox
 
 	box->pixmap = gdk_pixmap_new (widget->window, box->size.x, box->size.y, -1);
 
-	gdk_draw_rectangle (box->pixmap, widget->style->bg_gc[0], TRUE, 0, 0, box->size.x, box->size.y);
+	gdk_draw_rectangle (box->pixmap, widget->style->bg_gc[0], TRUE, 0, 0, box->size.x,
+			    box->size.y);
 
 	if (box->flags & (1 << GTK_DATABOX_SELECTION_ACTIVE))
 	{
@@ -536,7 +559,8 @@ gtk_databox_selection_cancel (GtkDatabox * box)
 	gtk_databox_draw_selection (box->draw, box, &rect);
 
 	/* Let everyone know that the selection has been cancelled */
-	g_signal_emit (GTK_OBJECT (box), gtk_databox_signals[GTK_DATABOX_SELECTION_CANCELLED_SIGNAL], 0);
+	g_signal_emit (GTK_OBJECT (box),
+		       gtk_databox_signals[GTK_DATABOX_SELECTION_CANCELLED_SIGNAL], 0);
 }
 
 static gint
@@ -563,7 +587,8 @@ gtk_databox_button_press (GtkWidget * widget, GdkEventButton * event, GtkDatabox
 		if ((button == 1 || button == 2)
 		    && x > MIN (box->marked.x, box->select.x)
 		    && x < MAX (box->marked.x, box->select.x)
-		    && y > MIN (box->marked.y, box->select.y) && y < MAX (box->marked.y, box->select.y))
+		    && y > MIN (box->marked.y, box->select.y)
+		    && y < MAX (box->marked.y, box->select.y))
 		{
 			gtk_databox_zoom_to_selection (widget, box);
 		}
@@ -588,7 +613,8 @@ gtk_databox_button_press (GtkWidget * widget, GdkEventButton * event, GtkDatabox
 	box->marked.x = x;
 	box->marked.y = y;
 
-	g_signal_emit (GTK_OBJECT (box), gtk_databox_signals[GTK_DATABOX_MARKED_SIGNAL], 0, &box->marked);
+	g_signal_emit (GTK_OBJECT (box), gtk_databox_signals[GTK_DATABOX_MARKED_SIGNAL], 0,
+		       &box->marked);
 
 	return FALSE;
 }
@@ -605,7 +631,8 @@ gtk_databox_button_release (GtkWidget * widget, GdkEventButton * event, GtkDatab
 
 		g_signal_emit (GTK_OBJECT (box),
 			       gtk_databox_signals
-			       [GTK_DATABOX_SELECTION_STOPPED_SIGNAL], 0, &box->marked, &box->select);
+			       [GTK_DATABOX_SELECTION_STOPPED_SIGNAL], 0, &box->marked,
+			       &box->select);
 	}
 
 	return FALSE;
@@ -649,7 +676,8 @@ gtk_databox_motion_notify (GtkWidget * widget, GdkEventMotion * event, GtkDatabo
 			box->select.x = x;
 			box->select.y = y;
 			g_signal_emit (GTK_OBJECT (box),
-				       gtk_databox_signals[GTK_DATABOX_SELECTION_STARTED_SIGNAL], 0, &box->marked);
+				       gtk_databox_signals[GTK_DATABOX_SELECTION_STARTED_SIGNAL], 0,
+				       &box->marked);
 		}
 
 		/* Determine the exposure rectangle (covering old selection and new) */
@@ -666,7 +694,8 @@ gtk_databox_motion_notify (GtkWidget * widget, GdkEventMotion * event, GtkDatabo
 
 		g_signal_emit (GTK_OBJECT (box),
 			       gtk_databox_signals
-			       [GTK_DATABOX_SELECTION_CHANGED_SIGNAL], 0, &box->marked, &box->select);
+			       [GTK_DATABOX_SELECTION_CHANGED_SIGNAL], 0, &box->marked,
+			       &box->select);
 	}
 
 	return FALSE;
@@ -703,7 +732,7 @@ gtk_databox_data_get_delta_value (GtkDatabox * box, GtkDataboxValue * coord)
 static void
 gtk_databox_data_calc_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDataboxValue * max)
 {
-	gint i;
+	guint i;
 	GtkDataboxData *data = NULL;
 	GList *list = NULL;
 	GtkDataboxValue border;
@@ -772,7 +801,8 @@ gtk_databox_data_get_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDatabo
 }
 
 void
-gtk_databox_data_get_visible_extrema (GtkDatabox * box, GtkDataboxValue * min, GtkDataboxValue * max)
+gtk_databox_data_get_visible_extrema (GtkDatabox * box, GtkDataboxValue * min,
+				      GtkDataboxValue * max)
 {
 /*   GtkDataboxValue pre_min;
    GtkDataboxValue pre_max;
@@ -884,7 +914,8 @@ gtk_databox_zoom_to_selection (GtkWidget * widget, GtkDatabox * box)
 	 * the left end of the visible "page" in scollbar-coordinates
 	 * (remember: we scroll from 0 to 1.0)
 	 */
-	box->adjX->value += (gfloat) (MIN (box->marked.x, box->select.x)) * box->adjX->page_size / box->size.x;
+	box->adjX->value +=
+		(gfloat) (MIN (box->marked.x, box->select.x)) * box->adjX->page_size / box->size.x;
 
 	/* The size of the selection box is used for calculating
 	 * the size of the visible "page" in scollbar-coordinates
@@ -897,7 +928,10 @@ gtk_databox_zoom_to_selection (GtkWidget * widget, GtkDatabox * box)
 	 */
 	if (box->adjX->page_size < box->zoom_limit)
 	{
-		box->adjX->value = (gfloat) MAX (0, box->adjX->value - (box->zoom_limit - box->adjX->page_size) / 2.0);
+		box->adjX->value =
+			(gfloat) MAX (0,
+				      box->adjX->value - (box->zoom_limit -
+							  box->adjX->page_size) / 2.0);
 		box->adjX->page_size = box->zoom_limit;
 	}
 
@@ -909,13 +943,17 @@ gtk_databox_zoom_to_selection (GtkWidget * widget, GtkDatabox * box)
 	box->adjY->lower = 0;
 	box->adjY->upper = 1.0;
 
-	box->adjY->value += (gfloat) (MIN (box->marked.y, box->select.y)) * box->adjY->page_size / box->size.y;
+	box->adjY->value +=
+		(gfloat) (MIN (box->marked.y, box->select.y)) * box->adjY->page_size / box->size.y;
 
 	box->adjY->page_size *= (gfloat) (ABS (box->marked.y - box->select.y) + 1) / box->size.y;
 
 	if (box->adjY->page_size < box->zoom_limit)
 	{
-		box->adjY->value = (gfloat) MAX (0, box->adjY->value - (box->zoom_limit - box->adjY->page_size) / 2.0);
+		box->adjY->value =
+			(gfloat) MAX (0,
+				      box->adjY->value - (box->zoom_limit -
+							  box->adjY->page_size) / 2.0);
 		box->adjY->page_size = box->zoom_limit;
 	}
 
@@ -935,8 +973,12 @@ gtk_databox_zoom_out (GtkWidget * widget, GtkDatabox * box)
 	box->adjY->lower = 0;
 	box->adjX->page_size = MIN (1.0, box->adjX->page_size * 2);
 	box->adjY->page_size = MIN (1.0, box->adjY->page_size * 2);
-	box->adjX->value = (box->adjX->page_size == 1.0) ? 0 : (MAX (0, (box->adjX->value - box->adjX->page_size / 4)));
-	box->adjY->value = (box->adjY->page_size == 1.0) ? 0 : (MAX (0, (box->adjY->value - box->adjY->page_size / 4)));
+	box->adjX->value =
+		(box->adjX->page_size ==
+		 1.0) ? 0 : (MAX (0, (box->adjX->value - box->adjX->page_size / 4)));
+	box->adjY->value =
+		(box->adjY->page_size ==
+		 1.0) ? 0 : (MAX (0, (box->adjY->value - box->adjY->page_size / 4)));
 	box->adjX->upper = 1.0;
 	box->adjY->upper = 1.0;
 	box->adjY->step_increment = box->adjY->page_size / 20;
@@ -993,7 +1035,8 @@ gtk_databox_zoomed (GtkWidget * widget, GtkDatabox * box, gboolean redraw_flag)
 	}
 
 	g_signal_emit (GTK_OBJECT (box),
-		       gtk_databox_signals[GTK_DATABOX_ZOOMED_SIGNAL], 0, &box->top_left, &box->bottom_right);
+		       gtk_databox_signals[GTK_DATABOX_ZOOMED_SIGNAL], 0, &box->top_left,
+		       &box->bottom_right);
 }
 
 static void
@@ -1038,7 +1081,8 @@ gtk_databox_ruler_x_update (GtkDatabox * box)
 	if (box->flags & (1 << GTK_DATABOX_SHOW_RULERS))
 	{
 		gtk_ruler_set_range (GTK_RULER (box->rulerX), box->top_left.x,
-				     box->bottom_right.x, 0.5 * (box->top_left.x + box->bottom_right.x), 20);
+				     box->bottom_right.x,
+				     0.5 * (box->top_left.x + box->bottom_right.x), 20);
 	}
 }
 
@@ -1048,7 +1092,8 @@ gtk_databox_ruler_y_update (GtkDatabox * box)
 	if (box->flags & (1 << GTK_DATABOX_SHOW_RULERS))
 	{
 		gtk_ruler_set_range (GTK_RULER (box->rulerY), box->top_left.y,
-				     box->bottom_right.y, 0.5 * (box->top_left.y + box->bottom_right.y), 20);
+				     box->bottom_right.y,
+				     0.5 * (box->top_left.y + box->bottom_right.y), 20);
 	}
 }
 
@@ -1082,7 +1127,9 @@ gtk_databox_draw_selection (GtkWidget * widget, GtkDatabox * box, GdkRectangle *
 
 		values.foreground = color;
 		values.function = GDK_XOR;
-		box->select_gc = gdk_gc_new_with_values (widget->window, &values, GDK_GC_FUNCTION | GDK_GC_FOREGROUND);
+		box->select_gc =
+			gdk_gc_new_with_values (widget->window, &values,
+						GDK_GC_FUNCTION | GDK_GC_FOREGROUND);
 	}
 
 
@@ -1092,7 +1139,8 @@ gtk_databox_draw_selection (GtkWidget * widget, GtkDatabox * box, GdkRectangle *
 			    flags & (1 << GTK_DATABOX_SHOW_SELECTION_FILLED),
 			    MIN (box->marked.x, box->select.x),
 			    MIN (box->marked.y, box->select.y),
-			    ABS (box->marked.x - box->select.x), ABS (box->marked.y - box->select.y));
+			    ABS (box->marked.x - box->select.x),
+			    ABS (box->marked.y - box->select.y));
 
 	/* Copy a part of the pixmap to the screen */
 	if (pixmapCopyRect)
@@ -1101,7 +1149,8 @@ gtk_databox_draw_selection (GtkWidget * widget, GtkDatabox * box, GdkRectangle *
 				   fg_gc[GTK_WIDGET_STATE (widget)],
 				   box->pixmap, pixmapCopyRect->x,
 				   pixmapCopyRect->y, pixmapCopyRect->x,
-				   pixmapCopyRect->y, pixmapCopyRect->width, pixmapCopyRect->height);
+				   pixmapCopyRect->y, pixmapCopyRect->width,
+				   pixmapCopyRect->height);
 }
 
 gint
@@ -1121,7 +1170,8 @@ gtk_databox_data_get_color (GtkDatabox * box, gint index, GdkColor * color)
 }
 
 gint
-gtk_databox_data_get_type (GtkDatabox * box, gint index, GtkDataboxDataType * type, guint * dot_size)
+gtk_databox_data_get_type (GtkDatabox * box, gint index, GtkDataboxDataType * type,
+			   guint * dot_size)
 {
 	GtkDataboxData *data = NULL;
 
@@ -1274,7 +1324,8 @@ gtk_databox_data_gc_new (GtkWidget * widget, GtkDatabox * box, GtkDataboxData *
 	data->gc =
 		gdk_gc_new_with_values (widget->window, &values,
 					GDK_GC_FUNCTION | GDK_GC_FOREGROUND |
-					GDK_GC_LINE_WIDTH | GDK_GC_LINE_STYLE | GDK_GC_CAP_STYLE | GDK_GC_JOIN_STYLE);
+					GDK_GC_LINE_WIDTH | GDK_GC_LINE_STYLE | GDK_GC_CAP_STYLE |
+					GDK_GC_JOIN_STYLE);
 
 	data->flags |= 1 << GTK_DATABOX_DATA_HAS_GC;
 }
@@ -1289,7 +1340,8 @@ gtk_databox_draw (GtkWidget * widget, GtkDatabox * box, GdkEventExpose * event)
 	if (!GTK_WIDGET_VISIBLE (widget))
 		return;
 
-	gdk_draw_rectangle (box->pixmap, widget->style->bg_gc[0], TRUE, 0, 0, box->size.x, box->size.y);
+	gdk_draw_rectangle (box->pixmap, widget->style->bg_gc[0], TRUE, 0, 0, box->size.x,
+			    box->size.y);
 
 	if (!box->data || !box->max_points)
 		return;
@@ -1330,8 +1382,8 @@ gtk_databox_draw (GtkWidget * widget, GtkDatabox * box, GdkEventExpose * event)
 static void
 gtk_databox_draw_points (GtkDatabox * box, GtkDataboxData * data)
 {
-	gint i = 0;
-	gint count = 0;
+	guint i = 0;
+	guint count = 0;
 
 
 	for (i = 0; i < data->length; i++)
@@ -1346,7 +1398,8 @@ gtk_databox_draw_points (GtkDatabox * box, GtkDataboxData * data)
 		   (Hint from Paul Barton-Davis <pbd@Op.Net>) */
 		for (i = 0; i < count; i += 65536)
 		{
-			gdk_draw_points (box->pixmap, data->gc, box->points + i, MIN (65536, count - i));
+			gdk_draw_points (box->pixmap, data->gc, box->points + i,
+					 MIN (65536, count - i));
 		}
 	}
 	else
@@ -1356,7 +1409,8 @@ gtk_databox_draw_points (GtkDatabox * box, GtkDataboxData * data)
 			/* Why on earth is there no gdk_draw_rectangles?? */
 			gdk_draw_rectangle (box->pixmap, data->gc, TRUE,
 					    box->points[i].x - data->size / 2,
-					    box->points[i].y - data->size / 2, data->size, data->size);
+					    box->points[i].y - data->size / 2, data->size,
+					    data->size);
 		}
 	}
 }
@@ -1364,7 +1418,7 @@ gtk_databox_draw_points (GtkDatabox * box, GtkDataboxData * data)
 static void
 gtk_databox_draw_lines (GtkDatabox * box, GtkDataboxData * data)
 {
-	gint i;
+	guint i;
 
 	for (i = 0; i < data->length; i++)
 	{
@@ -1376,22 +1430,24 @@ gtk_databox_draw_lines (GtkDatabox * box, GtkDataboxData * data)
 	   (Hint from Paul Barton-Davis <pbd@Op.Net>) */
 	for (i = 0; i < data->length; i += 65535)
 	{
-		gdk_draw_lines (box->pixmap, data->gc, box->points + i, MIN (65536, data->length - i));
+		gdk_draw_lines (box->pixmap, data->gc, box->points + i,
+				MIN (65536, data->length - i));
 	}
 }
 
 static void
 gtk_databox_draw_bars (GtkDatabox * box, GtkDataboxData * data)
 {
-	gint i = 0;
-	gint count = 0;
+	guint i = 0;
+	guint count = 0;
 	GdkSegment *segments = (GdkSegment *) box->points;
 	gfloat axis = 0;
 
 	axis = ((0 - box->top_left.y) * box->factor.y);
 	for (i = 0; i < data->length; i++)
 	{
-		segments[i].x1 = segments[i].x2 = (gint16) ((data->X[i] - box->top_left.x) * box->factor.x);
+		segments[i].x1 = segments[i].x2 =
+			(gint16) ((data->X[i] - box->top_left.x) * box->factor.x);
 		segments[i].y1 = axis;
 		segments[i].y2 = (gint16) ((data->Y[i] - box->top_left.y) * box->factor.y);
 	}
@@ -1415,7 +1471,8 @@ gtk_databox_draw_cross_simple (GtkDatabox * box, GtkDataboxData * data)
 		x = (0 - box->top_left.x) * box->factor.x;
 		if (x >= CROSS_BORDER && x < box->size.x - CROSS_BORDER)
 		{
-			gdk_draw_line (box->pixmap, data->gc, x, CROSS_BORDER, x, box->size.y - CROSS_BORDER);
+			gdk_draw_line (box->pixmap, data->gc, x, CROSS_BORDER, x,
+				       box->size.y - CROSS_BORDER);
 			xflag = TRUE;
 		}
 	}
@@ -1424,7 +1481,8 @@ gtk_databox_draw_cross_simple (GtkDatabox * box, GtkDataboxData * data)
 		y = (0 - box->top_left.y) * box->factor.y;
 		if (y >= CROSS_BORDER && y < box->size.y - CROSS_BORDER)
 		{
-			gdk_draw_line (box->pixmap, data->gc, CROSS_BORDER, y, box->size.x - CROSS_BORDER, y);
+			gdk_draw_line (box->pixmap, data->gc, CROSS_BORDER, y,
+				       box->size.x - CROSS_BORDER, y);
 			yflag = TRUE;
 		}
 	}
@@ -1472,7 +1530,9 @@ gtk_databox_data_add_x_y (GtkDatabox * box, guint length, gfloat * X,
 		/* We need twice as many GdkPoints, because draw bars uses segments 
 		 * and one segment equals two points.
 		 */
-		box->points = (GdkPoint *) g_realloc (box->points, sizeof (GdkPoint) * box->max_points * 2);
+		box->points =
+			(GdkPoint *) g_realloc (box->points,
+						sizeof (GdkPoint) * box->max_points * 2);
 	}
 	data = g_new0 (GtkDataboxData, 1);
 
@@ -1493,7 +1553,8 @@ gtk_databox_data_add_x_y (GtkDatabox * box, guint length, gfloat * X,
 
 gint
 gtk_databox_data_add_x (GtkDatabox * box, guint length, gfloat * X,
-			gint shared_Y_index, GdkColor color, GtkDataboxDataType type, guint dot_size)
+			gint shared_Y_index, GdkColor color, GtkDataboxDataType type,
+			guint dot_size)
 {
 	GtkDataboxData *data;
 
@@ -1509,7 +1570,8 @@ gtk_databox_data_add_x (GtkDatabox * box, guint length, gfloat * X,
 
 gint
 gtk_databox_data_add_y (GtkDatabox * box, guint length, gfloat * Y,
-			gint shared_X_index, GdkColor color, GtkDataboxDataType type, guint dot_size)
+			gint shared_X_index, GdkColor color, GtkDataboxDataType type,
+			guint dot_size)
 {
 	GtkDataboxData *data;
 
@@ -1574,7 +1636,8 @@ gtk_databox_data_check_y_links (GList * list, gfloat * values)
 }
 
 static void
-gtk_databox_data_destroy_internal (GtkDatabox * box, GtkDataboxData * data, GList * list, gboolean free_flag)
+gtk_databox_data_destroy_internal (GtkDatabox * box, GtkDataboxData * data, GList * list,
+				   gboolean free_flag)
 {
 	GdkColormap *colormap;
 
