@@ -245,7 +245,8 @@ keyb_get_consonants (gunichar * consonants)
 				consonants[k++] = chr;
 
 			chr = g_unichar_tolower (keyb.upchars[i][j]);
-			if (g_unichar_isalpha (chr) && (!keyb_is_vowel (chr)) && (chr != keyb.lochars[i][j]))
+			if (g_unichar_isalpha (chr) && (!keyb_is_vowel (chr))
+			    && (chr != keyb.lochars[i][j]))
 				consonants[k++] = chr;
 		}
 	return (k);
@@ -366,7 +367,8 @@ keyb_update_virtual_layout ()
 		for (j = 0; j < KEY_LINE_LEN - (i == 0 ? 1 : (i == 1 ? 2 : 3)); j++)
 		{
 			uch = tog_state ? keyb.upchars[i][j] : keyb.lochars[i][j];
-			if (g_unichar_isalpha (uch) && g_unichar_tolower (keyb.upchars[i][j]) == keyb.lochars[i][j])
+			if (g_unichar_isalpha (uch)
+			    && g_unichar_tolower (keyb.upchars[i][j]) == keyb.lochars[i][j])
 				uch = g_unichar_toupper (uch);
 			snprintf (lab_name + (i + 3), 3, "%i", j + 1);
 			if ((wg = lookup_widget (window_keyboard_, lab_name)))
@@ -402,7 +404,8 @@ keyb_fill_layout_list (gint entry_type)
 		 */
 		dir = g_dir_open (main_get_data_path (), 0, NULL);
 		if (dir == NULL)
-			g_error ("could not find the data directory:/n %s/n", main_get_data_path ());
+			g_error ("could not find the data directory:/n %s/n",
+				 main_get_data_path ());
 	}
 	else if (entry_type == 2 || entry_type == 3)
 	{
