@@ -27,6 +27,9 @@
 # define PACKAGE_DATA_DIR "..\\share"
 #endif
 
+#define LOCAL TRUE
+#define GLOBAL FALSE
+
 /*
  * Interface
  */
@@ -36,6 +39,8 @@ void main_set_data_path (gchar * path);
 
 gchar *main_get_user_dir (void);
 
+gchar *main_get_score_path (void);
+
 gboolean main_preferences_exist (gchar * group, gchar * key);
 
 void main_preferences_remove (gchar * group, gchar * key);
@@ -57,6 +62,8 @@ void main_preferences_set_boolean (gchar * group, gchar * key, gboolean value);
  */
 void main_initialize_global_variables (void);
 
+void main_set_auto_state (void);
+
 void main_window_init (void);
 
 void main_window_pass_away (void);
