@@ -24,6 +24,8 @@
 #include "gtkdatabox.h"
 #include "plot.h"
 
+# define PLOT_SCORE "#60C0F0"
+
 GtkWidget *window_stat_ = NULL;
 
 struct
@@ -86,6 +88,7 @@ plot_draw_chart (gint field)
 	gint i;
 	gint index;
 	guint64 aux;
+	gchar *tmp;
 	gchar *tmp_locale;
 	gchar *tmp_name;
 	gchar tmp_str[2000];
@@ -93,18 +96,27 @@ plot_draw_chart (gint field)
 	gfloat accur[DATA_POINTS];
 	gfloat velo[DATA_POINTS];
 	gfloat fluid[DATA_POINTS];
+	gfloat score[DATA_POINTS];
 	gchar data[DATA_POINTS][20];
 	gchar hour[DATA_POINTS][20];
-	gchar lesson[DATA_POINTS][199];
+	gint nchars[DATA_POINTS];
+	gchar lesson[DATA_POINTS][299];
 	GdkColor color;
 	GtkWidget *wg;
 	GtkDataboxValue max = { 0, 0 };
 	GtkDataboxValue min = { 0, 0 };
 
+	/* Blank the chart
+	 */
+	wg = lookup_widget (window_stat_, "databox_stat");
+	gtk_databox_data_remove_all (GTK_DATABOX (wg));
+	gtk_databox_redraw (GTK_DATABOX (wg));
+
 	/*
 	 * Formats the charts
 	 */
 	min.x = 0;
+	min.y = 0;
 	max.x = DATA_POINTS + 5;
 	max.y = 100;
 	wg = lookup_widget (window_stat_, "label_stat_unit");
@@ -116,14 +128,18 @@ plot_draw_chart (gint field)
 		break;
 
 	case 2:
-		min.y = 0;
 		gtk_label_set_text (GTK_LABEL (wg), _("Velocity (WPM)"));
 		break;
 
 	case 3:
-		min.y = 0;
 		gtk_label_set_text (GTK_LABEL (wg), _("Fluidness (%)"));
 		break;
+	case 4:
+		max.y = 10;
+		tmp = g_strconcat (_("Score"), " (0-10)", NULL);
+		gtk_label_set_text (GTK_LABEL (wg), tmp);
+		g_free (tmp);
+		break;
 	}
 	wg = lookup_widget (window_stat_, "databox_stat");
 	gtk_databox_rescale_with_values (GTK_DATABOX (wg), min, max);
@@ -136,12 +152,18 @@ plot_draw_chart (gint field)
 	if (aux == 0)
 		aux++;
 	sprintf (tmp_str, "%d", (gint) aux);
-	gtk_label_set_text (GTK_LABEL (lookup_widget (window_stat_, "label_stat_lesson_n")), tmp_str);
+	gtk_label_set_text (GTK_LABEL (lookup_widget (window_stat_, "label_stat_lesson_n")),
+			    tmp_str);
 
 	/*
 	 * Get the file name
 	 */
-	tmp_name = g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt", NULL);
+	if (field != 4)
+		tmp_name =
+			g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt",
+				     NULL);
+	else
+		tmp_name = g_strconcat (main_get_user_dir (), "scores_fluid.txt", NULL);
 
 	/*
 	 * Open the data file
@@ -179,14 +201,35 @@ plot_draw_chart (gint field)
 		plot.y_data[i] = -1000;
 
 	i = 0;
-	while (fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i], hour[i]) == 5)
+	while (1)
 	{
-		if (fgets (lesson[i], 199, fh) == NULL)
+		gint itens;
+
+		if (field < 4)
+			itens = fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i],
+					hour[i]);
+		else
+			itens = fscanf (fh, "%f%s%s%i", &score[i], data[i], hour[i], &nchars[i]);
+
+		if (itens != 5 && field < 4)
 			break;
-		if (strlen (lesson[i]) == 199)
-			g_warning
-				("file name of custom lesson too long in line %i of %s: the limit is 199 characters.",
-				 i, tmp_name);
+		else if (itens != 4 && field == 4)
+			break;
+
+		if (fgets (lesson[i], 299, fh) == NULL)
+			break;
+
+		if (strlen (lesson[i]) == 299)
+		{
+			if (field < 4)
+				g_warning
+					("file name of custom lesson too long in line %i of %s: "
+					 "the limit is 299 characters.", i, tmp_name);
+			else
+				g_warning
+					("language name too long in line %i of %s: "
+					 "the limit is 299 characters.", i, tmp_name);
+		}
 
 		if (accur[i] > 100)
 			accur[i] = 100;
@@ -200,6 +243,8 @@ plot_draw_chart (gint field)
 			fluid[i] = 100;
 		if (fluid[i] < 0)
 			fluid[i] = 0;
+		if (score[i] < 0)
+			score[i] = 0;
 
 		if (tutor_get_type () == TT_BASIC && g_ascii_strtoull (lesson[i], NULL, 10) != aux)
 			continue;
@@ -214,6 +259,9 @@ plot_draw_chart (gint field)
 		case 3:
 			plot.y_data[i] = fluid[i];
 			break;
+		case 4:
+			plot.y_data[i] = score[i];
+			break;
 		}
 		if (++i == DATA_POINTS)
 			break;
@@ -222,14 +270,34 @@ plot_draw_chart (gint field)
 	/*
 	 * Reads until the end, keeping the last DATA_POINTS points 
 	 */
-	while (fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i], hour[i]) == 5)
+	while (1)
 	{
-		if (fgets (lesson[i], 199, fh) == NULL)
+		gint itens;
+
+		if (field < 4)
+			itens = fscanf (fh, "%f%f%f%s%s", &accur[i], &velo[i], &fluid[i], data[i],
+					hour[i]);
+		else
+			itens = fscanf (fh, "%f%s%s%i", &score[i], data[i], hour[i], &nchars[i]);
+
+		if (itens != 5 && field < 4)
 			break;
-		if (strlen (lesson[i]) == 199)
-			g_warning
-				("file name of custom lesson too long in line %i of %s: the limit is 199 characters.",
-				 i, tmp_name);
+		else if (itens != 4 && field == 4)
+			break;
+
+		if (fgets (lesson[i], 299, fh) == NULL)
+			break;
+		if (strlen (lesson[i]) == 299)
+		{
+			if (field < 4)
+				g_warning
+					("file name of custom lesson too long in line %i of %s: "
+					 "the limit is 299 characters.", i, tmp_name);
+			else
+				g_warning
+					("language name too long in line %i of %s: "
+					 "the limit is 299 characters.", i, tmp_name);
+		}
 
 		if (accur[i] > 100)
 			accur[i] = 100;
@@ -243,6 +311,8 @@ plot_draw_chart (gint field)
 			fluid[i] = 100;
 		if (fluid[i] < 0)
 			fluid[i] = 0;
+		if (score[i] < 0)
+			score[i] = 0;
 
 		if (tutor_get_type () == TT_BASIC && g_ascii_strtoull (lesson[i], NULL, 10) != aux)
 			continue;
@@ -259,6 +329,9 @@ plot_draw_chart (gint field)
 		case 3:
 			plot.y_data[i] = fluid[i + 1];
 			break;
+		case 4:
+			plot.y_data[i] = score[i + 1];
+			break;
 		}
 		i++;
 	}
@@ -282,15 +355,21 @@ plot_draw_chart (gint field)
 	 * Replot the data
 	 */
 	wg = lookup_widget (window_stat_, "databox_stat");
-	gtk_databox_data_remove_all (GTK_DATABOX (wg));
-	gdk_color_parse (TUTOR_GREEN, &color);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_POINTS, 3);
+	if (field < 4)
+		gdk_color_parse (TUTOR_GREEN, &color);
+	else
+		gdk_color_parse (PLOT_SCORE, &color);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color,
+				  GTK_DATABOX_POINTS, 3);
 	gdk_color_parse (TUTOR_BLACK, &color);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_POINTS, 5);
-	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_LINES, 1);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color,
+				  GTK_DATABOX_POINTS, 5);
+	gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color,
+				  GTK_DATABOX_LINES, 1);
 
 	gdk_color_parse (TUTOR_YELLOW_GREEN, &color);
-	index = gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color, GTK_DATABOX_GRID, 1);
+	index = gtk_databox_data_add_x_y (GTK_DATABOX (wg), i, plot.x_data, plot.y_data, color,
+					  GTK_DATABOX_GRID, 1);
 	gtk_databox_data_set_grid_config (GTK_DATABOX (wg), index, 9, 10);
 
 	/*
