@@ -31,6 +31,7 @@
 "Nederlands - Nederland (nl_NL)\n" \
 "Polski (pl_PL)\n" \
 "Português - Brasil (pt_BR)\n" \
+"Русский (ru_RU)\n" \
 "Svenska (sv_SE)";
 
 #define LANG_NAME_MAX_LEN 50
@@ -38,16 +39,21 @@ typedef struct
 {
 	gchar name[LANG_NAME_MAX_LEN];
 	gchar code[6];
+	gchar cd[3];
 } Lang_Name_Code;
 
 void trans_set_language_env (gchar * code);
 
 void trans_init_lang_name_code (void);
 
+gchar * trans_get_code (gint i);
+
 void trans_init_language_env (void);
 
 void trans_set_combo_language (void);
 
+gchar *trans_get_current_language (void);
+
 void trans_change_language (void);
 
 FILE *trans_lang_get_similar_file (const gchar * file_end);
