@@ -29,6 +29,7 @@
 #include "adaptability.h"
 #include "velocity.h"
 #include "fluidness.h"
+#include "top10.h"
 #include "tutor.h"
 
 /*
@@ -99,6 +100,7 @@ tutor_init (TutorType tt_type)
 	gchar *tmp_title = NULL;
 	gchar *tmp_name = NULL;
 	GtkWidget *wg;
+	GtkTooltipsData *tt;
 
 	if (window_tutor_ == NULL)
 		window_tutor_ = create_window_tutor ();
@@ -112,9 +114,10 @@ tutor_init (TutorType tt_type)
 	cursor_set_is_initializing (FALSE);
 
 
-  /******************************
-   * Set the layout for each exercise type
-   */
+	/******************************
+	 * Set the layout for each exercise type
+	 */
+	gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_top10"));
 	if (tutor.type == TT_BASIC || tutor.type == TT_FLUID)
 	{
 		gtk_widget_show (lookup_widget (window_tutor_, "frame_lesson"));
@@ -124,20 +127,27 @@ tutor_init (TutorType tt_type)
 			gtk_widget_show (lookup_widget (window_tutor_, "button_revert_lesson"));
 			gtk_widget_show (lookup_widget (window_tutor_, "button_reset_lesson"));
 			gtk_widget_show (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
-			gtk_label_set_text (GTK_LABEL (lookup_widget (window_tutor_, "label_lesson")), _("Lesson:"));
+			gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_top10"));
+			gtk_label_set_text (GTK_LABEL
+					    (lookup_widget (window_tutor_, "label_lesson")),
+					    _("Lesson:"));
 			gtk_spin_button_set_range (GTK_SPIN_BUTTON
-						   (lookup_widget (window_tutor_, "spinbutton_lesson")), 1, 50);
+						   (lookup_widget
+						    (window_tutor_, "spinbutton_lesson")), 1, 50);
 		}
 		else
 		{
 			gtk_widget_hide (lookup_widget (window_tutor_, "button_revert_lesson"));
 			gtk_widget_hide (lookup_widget (window_tutor_, "button_reset_lesson"));
 			gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
+			gtk_widget_show (lookup_widget (window_tutor_, "button_tutor_top10"));
 			gtk_label_set_text (GTK_LABEL
-					    (lookup_widget (window_tutor_, "label_lesson")), _("Paragraphs:"));
+					    (lookup_widget (window_tutor_, "label_lesson")),
+					    _("Paragraphs:"));
 			callbacks_shield = TRUE;
 			gtk_spin_button_set_range (GTK_SPIN_BUTTON
-						   (lookup_widget (window_tutor_, "spinbutton_lesson")), 1, 10);
+						   (lookup_widget
+						    (window_tutor_, "spinbutton_lesson")), 1, 10);
 			callbacks_shield = FALSE;
 		}
 	}
@@ -146,6 +156,7 @@ tutor_init (TutorType tt_type)
 		gtk_widget_hide (lookup_widget (window_tutor_, "frame_lesson"));
 		gtk_widget_hide (lookup_widget (window_tutor_, "vseparator_tutor"));
 		gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_show_keyb"));
+		gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_top10"));
 		basic_set_lesson (0);
 	}
 
@@ -155,9 +166,10 @@ tutor_init (TutorType tt_type)
 	else
 		gtk_widget_show (wg);
 
-  /******************************
-   * Set decoration texts
-   */
+	/******************************
+	 * Set decoration texts and tips
+	 */
+
 	switch (tutor.type)
 	{
 	case TT_BASIC:
@@ -180,7 +192,8 @@ tutor_init (TutorType tt_type)
 
 	case TT_FLUID:
 		tmp_title = g_strdup (_("Klavaro - Fluidness"));
-		tmp_name = g_strdup (_("Fluidness exercises: accuracy typing good sense paragraphs."));
+		tmp_name =
+			g_strdup (_("Fluidness exercises: accuracy typing good sense paragraphs."));
 		break;
 	}
 	gtk_window_set_title (GTK_WINDOW (window_tutor_), tmp_title);
@@ -189,18 +202,27 @@ tutor_init (TutorType tt_type)
 	g_free (tmp_title);
 	g_free (tmp_name);
 
-  /******************************
-   * Set specific variables
-   */
+	/******************************
+	 * Set tooltips of tutor entry (drag and drop)
+	 */
+	wg = lookup_widget (window_tutor_, "entry_mesg");
+	tt = gtk_tooltips_data_get (wg);
+	if (tutor.type == TT_VELO || tutor.type == TT_FLUID)
+		gtk_tooltips_set_tip (tt->tooltips, wg,
+				      _("Drag and drop text here to practice with it."), NULL);
+	else
+		gtk_tooltips_set_tip (tt->tooltips, wg, ";-)", NULL);
+
+	/******************************
+	 * Set specific variables
+	 */
 	if (tutor.type == TT_BASIC)
 	{
 		basic_init ();
 		return;
 	}
-
 	else if (tutor.type == TT_VELO)
 		velo_init ();
-
 	else if (tutor.type == TT_FLUID)
 		fluid_init ();
 
@@ -233,11 +255,16 @@ tutor_update ()
 
 	case QUERY_END:
 		if (tutor.type == TT_BASIC)
-			tutor_message (_("<<==  End of lesson." " Press [Enter] to start another. ==>> "));
+			tutor_message (_
+				       ("<<==  End of lesson."
+					" Press [Enter] to start another. ==>> "));
 		else
-			tutor_message (_("<<==  End of exercise." " Press [Enter] to start another. ==>> "));
+			tutor_message (_
+				       ("<<==  End of exercise."
+					" Press [Enter] to start another. ==>> "));
 		gtk_widget_hide (lookup_widget (window_tutor_, "button_tutor_restart"));
-		gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"), FALSE);
+		gtk_widget_set_sensitive (lookup_widget (window_tutor_, "button_tutor_font"),
+					  FALSE);
 		break;
 	}
 }
@@ -256,7 +283,8 @@ tutor_update_intro ()
 	{
 		callbacks_shield = TRUE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON
-					   (lookup_widget (window_tutor_, "spinbutton_lesson")), basic_get_lesson ());
+					   (lookup_widget (window_tutor_, "spinbutton_lesson")),
+					   basic_get_lesson ());
 		callbacks_shield = FALSE;
 
 		wg_label = GTK_LABEL (lookup_widget (window_tutor_, "label_heading"));
@@ -307,7 +335,8 @@ tutor_update_start ()
 	{
 		callbacks_shield = TRUE;
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (lookup_widget
-							    (window_tutor_, "spinbutton_lesson")), basic_get_lesson ());
+							    (window_tutor_, "spinbutton_lesson")),
+					   basic_get_lesson ());
 		callbacks_shield = FALSE;
 
 		if (main_preferences_exist ("tutor", "basic_lesson"))
@@ -637,9 +666,10 @@ tutor_eval_forward_backward (gunichar user_chr)
 void
 tutor_calc_stats ()
 {
-	gint i;
+	guint i = 0;
 	gint minutes;
 	gint seconds;
+	gboolean may_log = TRUE;
 	gdouble accuracy;
 	gdouble touchs_per_second;
 	gdouble velocity;
@@ -648,15 +678,17 @@ tutor_calc_stats ()
 	gdouble sum;
 	gdouble average = 0;
 	gdouble sample;
+	gchar *contest_ps = NULL;
 	gchar *tmp_locale;
 	gchar *tmp_str = NULL;
-	gchar *tmp_str2;
+	gchar *tmp_str2 = NULL;
 	gchar *tmp_name;
 	FILE *fh;
 	time_t tmp_time;
 	struct tm *ltime;
 	GtkWidget *wg;
 	GtkTextBuffer *buf;
+	Statistics stat;
 
 	/*
 	 * Calculate statistics
@@ -704,85 +736,170 @@ tutor_calc_stats ()
 	else
 		fluidness = 0;
 
-	/*
-	 * Changing to "C" locale: remember to copy the previous value!
+	/* Verify if logging is allowed 
 	 */
-	tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
-	if (tmp_locale != NULL)
-		setlocale (LC_NUMERIC, "C");
-
-	/*
-	 * Logging
-	 */
-	tmp_name = g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt", NULL);
-	assert_user_dir ();
-	if (!(fh = (FILE *) g_fopen (tmp_name, "r")))
-	{
-		fh = (FILE *) g_fopen (tmp_name, "w");
-		fprintf (fh, "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\n");
-	}
-	else
-	{
-		fclose (fh);
-		fh = (FILE *) g_fopen (tmp_name, "a");
-	}
-	if (fh)
-	{
-		tmp_time = time (NULL);
-		ltime = localtime (&tmp_time);
-		fprintf (fh,
-			 "%.2f\t%.2f\t%.2f\t%i-%2.2i-%2.2i\t%2.2i:%2.2i\t",
-			 accuracy, velocity, fluidness,
-			 (ltime->tm_year) + 1900, (ltime->tm_mon) + 1,
-			 (ltime->tm_mday), (ltime->tm_hour), (ltime->tm_min));
-		switch (tutor.type)
+	may_log = TRUE;
+	if (tutor.type == TT_VELO || tutor.type == TT_FLUID)
+		if (tutor.n_touchs - tutor.n_errors < MIN_CHARS_TO_LOG)
 		{
-		case TT_BASIC:
-			fprintf (fh, "%2.2i\n", basic_get_lesson ());
-			break;
-		case TT_ADAPT:
-			fprintf (fh, "%s\n", _("Default"));
-			break;
-		case TT_VELO:
-			fprintf (fh, "%s\n", velo_get_dict_name ());
-			break;
-		case TT_FLUID:
-			fprintf (fh, "%s\n", fluid_get_paragraph_name ());
+			gdk_beep (); gdk_beep ();
+			contest_ps = g_strdup_printf (_("ps.: logging not performed for this session: "
+				   "the number of typed characters (%i) must be greater than %i."),
+				   tutor.n_touchs - tutor.n_errors, MIN_CHARS_TO_LOG);
+			may_log = FALSE;
 		}
-		fclose (fh);
-	}
-	else
-		g_message ("not able to log on this file:\n %s", tmp_name);
-	g_free (tmp_name);
-
-	if (tutor.type == TT_FLUID)
+	if (may_log)
 	{
 		/*
-		 * Logging the fluidness results of the last session
+		 * Changing to "C" locale: remember to copy the previous value!
 		 */
-		tmp_name = g_strconcat (main_get_user_dir (), "deviation_fluid.txt", NULL);
-		if ((fh = (FILE *) g_fopen (tmp_name, "w")))
+		tmp_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
+		if (tmp_locale != NULL)
+			setlocale (LC_NUMERIC, "C");
+
+		/*
+		 * Logging
+		 */
+		tmp_name =
+			g_strconcat (main_get_user_dir (), "stat_", tutor_get_type_name (), ".txt",
+				     NULL);
+		assert_user_dir ();
+		if (!(fh = (FILE *) g_fopen (tmp_name, "r")))
 		{
-			g_message ("writing further fluidness results at:\n %s", tmp_name);
+			fh = (FILE *) g_fopen (tmp_name, "w");
 			fprintf (fh,
-				 "(i)\tdt(i)\tsqrt(1/dt(i))\tAverage:\t%g\tStd. dev.:\t%g\n",
-				 average, standard_deviation);
-			for (i = 1; i < tutor.ttidx; i++)
-				fprintf (fh, "%i\t%g\t%g\n", i, tutor.touch_time[i],
-					 sqrt (1 / (tutor.touch_time[i] > 0 ? tutor.touch_time[i] : 1.0e-9)));
+				 "Accuracy\tVelocity\tFluidness\tDate\tHour\tLesson\tLanguage\n");
+		}
+		else
+		{
+			fclose (fh);
+			fh = (FILE *) g_fopen (tmp_name, "a");
+		}
+		if (fh)
+		{
+			tmp_time = time (NULL);
+			ltime = localtime (&tmp_time);
+			fprintf (fh,
+				 "%.2f\t%.2f\t%.2f\t%i-%2.2i-%2.2i\t%2.2i:%2.2i\t",
+				 accuracy, velocity, fluidness,
+				 (ltime->tm_year) + 1900, (ltime->tm_mon) + 1,
+				 (ltime->tm_mday), (ltime->tm_hour), (ltime->tm_min));
+			switch (tutor.type)
+			{
+			case TT_BASIC:
+				fprintf (fh, "%2.2i\t", basic_get_lesson ());
+				break;
+			case TT_ADAPT:
+				fprintf (fh, "%s\t", _("Default"));
+				break;
+			case TT_VELO:
+				fprintf (fh, "%s\t", velo_get_dict_name ());
+				break;
+			case TT_FLUID:
+				fprintf (fh, "%s\t", fluid_get_paragraph_name ());
+			}
+
+			fprintf (fh, "%s\n", trans_get_current_language ());
+
 			fclose (fh);
 		}
 		else
 			g_message ("not able to log on this file:\n %s", tmp_name);
 		g_free (tmp_name);
-	}
 
-	/*
-	 * Coming back to the right locale
-	 */
-	if (tmp_locale != NULL)
-		setlocale (LC_NUMERIC, tmp_locale);
-	g_free (tmp_locale);
+		if (tutor.type == TT_FLUID)
+		{
+			/* Log the fluidness results of the last session
+			 */
+			tmp_name = g_strconcat (main_get_user_dir (), "deviation_fluid.txt", NULL);
+			if ((fh = (FILE *) g_fopen (tmp_name, "w")))
+			{
+				g_message ("writing further fluidness results at:\n %s", tmp_name);
+				fprintf (fh,
+					 "(i)\tdt(i)\tsqrt(1/dt(i))\tAverage:\t%g\tStd. dev.:\t%g\n",
+					 average, standard_deviation);
+				for (i = 1; i < tutor.ttidx; i++)
+					fprintf (fh, "%i\t%g\t%g\n", i, tutor.touch_time[i],
+						 sqrt (1 /
+						       (tutor.touch_time[i] >
+							0 ? tutor.touch_time[i] : 1.0e-9)));
+				fclose (fh);
+			}
+			else
+				g_message ("not able to log on this file:\n %s", tmp_name);
+			g_free (tmp_name);
+
+			/* Add results to Top 10
+			 */
+			tmp_name = main_preferences_get_string ("interface", "language");
+			stat.lang[0] = tmp_name[0] == 'C' ? 'e' : tmp_name[0];
+			stat.lang[1] = tmp_name[1] ? tmp_name[i] : 'n';
+			stat.genv = UNIX_OK ? 'x' : 'w';
+			stat.when = time (NULL);
+			stat.nchars = tutor.n_touchs - tutor.n_errors;
+			stat.accur = accuracy;
+			stat.velo = velocity;
+			stat.fluid = fluidness;
+
+			stat.score = top10_calc_score (&stat);
+			stat.name_len = strlen (g_get_real_name ());
+			if (stat.name_len > MAX_NAME_LEN)
+				stat.name_len = MAX_NAME_LEN;
+			strncpy (stat.name, g_get_real_name (), stat.name_len + 1);
+			g_free (tmp_name);
+
+			top10_read_stats (LOCAL, -1);
+			if (tutor_char_distribution_approved ())
+			{
+				if (top10_compare_insert_stat (&stat, LOCAL))
+				{
+					contest_ps =
+						g_strdup (_
+							  ("ps.: you have entered the Top 10 list, great!"));
+					top10_write_stats (LOCAL, -1);
+				}
+			}
+			else
+				contest_ps =
+					g_strdup (_
+						  ("ps.: the text you just typed doesn't seem to be similar"
+						   " to ordinary texts in the language currently selected:"
+						   " we can't account for it in the 'Top 10' contest."));
+
+			/* Anyway, log also the scoring
+			 */
+			tmp_name =
+				g_build_filename (main_get_user_dir (), "scores_fluid.txt", NULL);
+			assert_user_dir ();
+			if (!g_file_test (tmp_name, G_FILE_TEST_IS_REGULAR))
+			{
+				fh = (FILE *) g_fopen (tmp_name, "w");
+				fprintf (fh,
+					 "Score\tDate\tTime\tNumber of chars\tLanguage\n");
+			}
+			else
+				fh = (FILE *) g_fopen (tmp_name, "a");
+			if (fh)
+			{
+				ltime = localtime (&stat.when);
+				fprintf (fh,
+					 "%3.4f\t%i-%2.2i-%2.2i\t%2.2i:%2.2i\t%i\t%s\n",
+					 stat.score, (ltime->tm_year) + 1900, (ltime->tm_mon) + 1, (ltime->tm_mday),
+					 (ltime->tm_hour), (ltime->tm_min), stat.nchars, trans_get_current_language ());
+				fclose (fh);
+			}
+			else
+				g_message ("not able to log on this file:\n %s", tmp_name);
+			g_free (tmp_name);
+		}
+
+		/*
+		 * Coming back to the right locale
+		 */
+		if (tmp_locale != NULL)
+			setlocale (LC_NUMERIC, tmp_locale);
+		g_free (tmp_locale);
+	}
 
 	/*
 	 * Print statistics
@@ -827,8 +944,11 @@ tutor_calc_stats ()
 				       " %.2f\t\t", _("Goal:"), " %i ",
 				       _("(CPS)"), "\n",
 				       _("Words per minute:"), " %.1f\t\t",
-				       _("Goal:"), " %i ", _("(WPM)"), "\n\n", _("Comments:"), "\n", NULL);
-		tmp_str2 = g_strdup_printf (tmp_str, minutes, seconds, accuracy, 97, velocity / 10, 5, velocity, 50);
+				       _("Goal:"), " %i ", _("(WPM)"), "\n\n", _("Comments:"), "\n",
+				       NULL);
+		tmp_str2 =
+			g_strdup_printf (tmp_str, minutes, seconds, accuracy, 97, velocity / 10, 5,
+					 velocity, 50);
 		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		velo_comment (accuracy, velocity);
 		break;
@@ -849,10 +969,17 @@ tutor_calc_stats ()
 				       _("Fluidness:"), " %.1f %%\t\t",
 				       _("Goal:"), " %i %%\n\n", _("Comments:"), "\n", NULL);
 		tmp_str2 =
-			g_strdup_printf (tmp_str, minutes, seconds, accuracy, 98, velocity / 10, 5, velocity, 50,
-					 fluidness, 90);
+			g_strdup_printf (tmp_str, minutes, seconds, accuracy, 98, velocity / 10, 5,
+					 velocity, 50, fluidness, 80);
 		gtk_text_buffer_insert_at_cursor (buf, tmp_str2, strlen (tmp_str2));
 		fluid_comment (accuracy, velocity, fluidness);
+
+		if (contest_ps != NULL)
+		{
+			gtk_text_buffer_insert_at_cursor (buf, "\n", 1);
+			gtk_text_buffer_insert_at_cursor (buf, contest_ps, strlen (contest_ps));
+			g_free (contest_ps);
+		}
 	}
 	g_free (tmp_str);
 	g_free (tmp_str2);
@@ -860,6 +987,179 @@ tutor_calc_stats ()
 	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (wg), gtk_text_buffer_get_insert (buf));
 }
 
+/**********************************************************************
+ * Ensure the user is not trying to type with weird texts in the fluidness contest
+ */
+#define DECEIVENESS_LIMIT 0.195
+gboolean
+tutor_char_distribution_approved ()
+{
+	guint i, j;
+	gfloat deceiveness;
+	gchar *tmp_code;
+	gchar *tmp_name;
+
+	struct MODEL
+	{
+		gchar *text;
+		Char_Distribution dist;
+	} model;
+
+	struct EXAM
+	{
+		gchar *text;
+		Char_Distribution dist;
+	} exam;
+
+	GtkWidget *wg;
+	GtkTextBuffer *buf;
+	GtkTextIter start;
+	GtkTextIter end;
+
+	/* Get model text
+	 */
+	tmp_code = main_preferences_get_string ("interface", "language");
+	tmp_name = g_strconcat (main_get_data_path (), tmp_code, ".paragraphs", NULL);
+	g_free (tmp_code);
+	if (!g_file_get_contents (tmp_name, &model.text, NULL, NULL))
+	{
+		g_message ("Can't read file:\n %s\n So, not logging your score.", tmp_name);
+		g_free (tmp_name);
+		return FALSE;
+	}
+	g_free (tmp_name);
+
+	/* Get text under examination
+	 */
+	wg = lookup_widget (window_tutor_, "text_tutor");
+	buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (wg));
+	gtk_text_buffer_get_bounds (buf, &start, &end);
+	exam.text = gtk_text_buffer_get_text (buf, &start, &end, FALSE);
+
+	/* Get char distributions
+	 */
+	tutor_char_distribution_count (model.text, &model.dist);
+	tutor_char_distribution_count (exam.text, &exam.dist);
+
+	/* Compare both distributions
+	 */
+	deceiveness = 0;
+	for (i = 0; i < 9 && deceiveness < 1.0e+6; i++)
+	{
+		for (j = 0; j < exam.dist.size; j++)
+			if (model.dist.ch[i].letter == exam.dist.ch[j].letter)
+			{
+				deceiveness +=
+					powf ((exam.dist.ch[j].freq - model.dist.ch[i].freq), 2);
+				break;
+			}
+		if (j == exam.dist.size)
+		{
+			deceiveness += 1.0e+7;
+			break;
+		}
+	}
+	deceiveness = sqrtf (deceiveness / 9);
+
+	g_free (model.text);
+	g_free (exam.text);
+
+
+	if (deceiveness < DECEIVENESS_LIMIT)
+		return TRUE;
+	else
+	{
+		g_print ("Deceiveness: %g. Should be lesser than %g.\n", deceiveness,
+			 DECEIVENESS_LIMIT);
+		return FALSE;
+	}
+}
+
+/**********************************************************************
+ * Count relative frequency of letters in text
+ */
+void
+tutor_char_distribution_count (gchar * text, Char_Distribution * dist)
+{
+	gchar *pt;
+	gunichar ch;
+	gsize i, j;
+
+	pt = text;
+
+	dist->size = 0;
+	dist->total = 0;
+	while ((ch = g_utf8_get_char (pt)) != L'\0')
+	{
+		/* Only count letters
+		 */
+		if (!g_unichar_isalpha (ch))
+		{
+			pt = g_utf8_next_char (pt);
+			continue;
+		}
+		ch = g_unichar_tolower (ch);
+
+		/* Verify if ch was already counted
+		 */
+		for (i = 0; i < dist->size; i++)
+		{
+			if (ch == dist->ch[i].letter)
+			{
+				dist->ch[i].count++;
+				dist->total++;
+				break;
+			}
+		}
+
+		/* If ch was not counted yet, start to do it
+		 */
+		if (i == dist->size && i < MAX_ALPHABET_LEN)
+		{
+			dist->ch[dist->size].letter = ch;
+			dist->ch[dist->size].count = 1;
+			dist->total++;
+			dist->size++;
+		}
+
+		pt = g_utf8_next_char (pt);
+	}
+
+	/* Sort the list
+	 */
+	for (i = 1; i < dist->size; i++)
+	{
+		gunichar aletter;
+		guint acount;
+
+		if (dist->ch[i].count > dist->ch[i - 1].count)
+			for (j = i; j > 0; j--)
+			{
+				if (dist->ch[j].count <= dist->ch[j - 1].count)
+					break;
+
+				aletter = dist->ch[j - 1].letter;
+				dist->ch[j - 1].letter = dist->ch[j].letter;
+				dist->ch[j].letter = aletter;
+
+				acount = dist->ch[j - 1].count;
+				dist->ch[j - 1].count = dist->ch[j].count;
+				dist->ch[j].count = acount;
+			}
+	}
+
+	/* Write the relative frequency
+	 */
+	for (i = 0; i < dist->size; i++)
+		dist->ch[i].freq = ((gfloat) dist->ch[i].count) / ((gfloat) dist->ch[0].count);
+
+	/*
+	   for (i = 0; i < dist->size; i++)
+	   g_message ("Char: %x, count: %u, freq:%g", dist->ch[i].letter, dist->ch[i].count, dist->ch[i].freq);
+	   g_message ("Total: %u  / Size: %u ------------------------------", dist->total, dist->size);
+	 */
+}
+
 /**********************************************************************
  * Formats and draws one paragraph at the tutor window
  */
