@@ -20,6 +20,7 @@
 # define TUTOR_BLACK "#000000"
 # define TUTOR_WHITE "#FFFFF8"
 
+
 typedef enum
 {
 	TT_BASIC,
@@ -36,6 +37,19 @@ typedef enum
 	QUERY_END
 } TutorQuery;
 
+#define MAX_ALPHABET_LEN 50
+typedef struct CHAR_DISTRIBUTION
+{
+	struct CHARS
+	{
+		gunichar letter;
+		guint count;
+		gfloat freq;
+	} ch[MAX_ALPHABET_LEN];
+	guint size;
+	guint total;
+} Char_Distribution;
+
 /*
  * Interface functions
  */
@@ -68,6 +82,10 @@ gboolean tutor_eval_forward_backward (gunichar chr);
 
 void tutor_calc_stats (void);
 
+gboolean tutor_char_distribution_approved (void);
+
+void tutor_char_distribution_count (gchar * text, Char_Distribution * dist);
+
 void tutor_draw_paragraph (gchar * text);
 
 void tutor_message (gchar * mesg);
