@@ -7,8 +7,7 @@
 /*  which is also included in this package, in a file named "COPYING".    */
 /**************************************************************************/
 
-#define MAX_LINES 100
-#define MAX_LINE_LEN 2001
+#define MAX_WORDS 3000
 
 /*
  * Interface functions
@@ -28,6 +27,10 @@ void velo_draw_random_words (void);
 
 void velo_get_random_word (gchar *);
 
-void velo_create_dict (gchar *, gboolean);
+gchar *velo_filter_utf8 (gchar * text);
+
+void velo_text_write_to_file (gchar * text_raw, gboolean overwrite);
+
+void velo_create_dict (gchar * file_name, gboolean overwrite);
 
 void velo_comment (gdouble accuracy, gdouble velocity);
